VestingPoolInfo class

Inheritance

Constructors

VestingPoolInfo({String? name, String? vestingType, Timestamp? lockStart, Timestamp? lockEnd, String? withdrawable, Coin? initiallyLocked, String? currentlyLocked, String? sentAmount, List<VestingPoolReservation> reservations = const []})
const
VestingPoolInfo.deserialize(List<int> bytes)
factory
VestingPoolInfo.fromJson(Map<String, dynamic> json)
factory

Properties

currentlyLocked String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
initiallyLocked Coin?
final
lockEnd Timestamp?
final
lockStart Timestamp?
final
name String?
final
protoValues List<Object?>
no setteroverride
reservations List<VestingPoolReservation>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentAmount String?
final
vestingType String?
final
withdrawable String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig