MsgCreateVestingAccount class

Inheritance
Mixed-in types

Constructors

MsgCreateVestingAccount({String? fromAddress, String? toAddress, List<Coin> amount = const [], BigInt? startTime, BigInt? endTime})
const
MsgCreateVestingAccount.deserialize(List<int> bytes)
factory
MsgCreateVestingAccount.fromJson(Map<String, dynamic> json)
factory

Properties

amount List<Coin>
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
endTime BigInt?
final
fromAddress String?
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime BigInt?
final
toAddress String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateVestingAccountResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateVestingAccountResponse
override
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig