MsgCreateVestingPool class

this line is used by starport scaffolding # proto/tx/rpc

Inheritance
Mixed-in types

Constructors

MsgCreateVestingPool({String? owner, String? name, String? amount, Duration? duration, String? vestingType})
const
MsgCreateVestingPool.deserialize(List<int> bytes)
factory
MsgCreateVestingPool.fromJson(Map<String, dynamic> json)
factory

Properties

amount String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
duration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
owner String?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vestingType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateVestingPoolResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateVestingPoolResponse
override
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig