ModuleConfig class
ModuleConfig is a module configuration for an app.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- ModuleConfig
Constructors
-
ModuleConfig({String? name, Any? config, List<
GolangBinding> golangBindings = const []}) -
const
-
ModuleConfig.deserialize(List<
int> bytes) -
factory
-
ModuleConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- config → Any?
-
config is the config object for the module. Module config messages should
define a ModuleDescriptor using the cosmos.app.v1alpha1.is_module extension.
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
-
golangBindings
→ List<
GolangBinding> -
golang_bindings specifies explicit interface to implementation type bindings which
depinject uses to resolve interface inputs to provider functions. The scope of this
field's configuration is module specific.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
name is the unique name of the module within the app. It should be a name
that persists between different versions of a module so that modules
can be smoothly upgraded to new versions.
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig