info property
info is the account info which is represented by BaseAccount.
Implementation
final cosmos_auth_v1beta1_auth.BaseAccount? info;
info is the account info which is represented by BaseAccount.
final cosmos_auth_v1beta1_auth.BaseAccount? info;