toJson method
Dont change order of toJson the key index must be equal to protoConfig fields.
Implementation
@override
Map<String, dynamic> toJson() {
return {'accounts': accounts.map((e) => e.toJson()).toList()};
}
Dont change order of toJson the key index must be equal to protoConfig fields.
@override
Map<String, dynamic> toJson() {
return {'accounts': accounts.map((e) => e.toJson()).toList()};
}