ModuleOptions class

ModuleOptions describes the CLI options for a Cosmos SDK module.

Inheritance

Constructors

ModuleOptions({ServiceCommandDescriptor? tx, ServiceCommandDescriptor? query})
const
ModuleOptions.deserialize(List<int> bytes)
factory
ModuleOptions.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
query ServiceCommandDescriptor?
query describes the queries commands for the module.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tx ServiceCommandDescriptor?
tx describes the tx commands for the module.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig