metadata property
metadata describes and provides all the client information for the requested token.
Implementation
final cosmos_bank_v1beta1_bank.Metadata? metadata;
metadata describes and provides all the client information for the requested token.
final cosmos_bank_v1beta1_bank.Metadata? metadata;