QuerySendEnabledRequest class

QuerySendEnabledRequest defines the RPC request for looking up SendEnabled entries.

Inheritance
Mixed-in types

Constructors

QuerySendEnabledRequest({List<String> denoms = const [], PageRequest? pagination})
const
QuerySendEnabledRequest.deserialize(List<int> bytes)
factory
QuerySendEnabledRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
denoms List<String>
denoms is the specific denoms you want look up. Leave empty to get all entries.
final
hashCode int
The hash code for this object.
no setterinherited
pagination PageRequest?
pagination defines an optional pagination for the request. This field is only read if the denoms field is empty.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QuerySendEnabledResponse
override
onQueryResponseJson(Map<String, dynamic> json) QuerySendEnabledResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig