proto_messages/cosmos/base/node/v1beta1/models library
Classes
- ConfigRequest
- ConfigRequest defines the request structure for the Config gRPC query.
- ConfigResponse
- ConfigResponse defines the response structure for the Config gRPC query.
- StatusRequest
- StateRequest defines the request structure for the status of a node.
- StatusResponse
- StateResponse defines the response structure for the status of a node.