StatusResponse class

StateResponse defines the response structure for the status of a node.

Inheritance

Constructors

StatusResponse({BigInt? earliestStoreHeight, BigInt? height, Timestamp? timestamp, List<int>? appHash, List<int>? validatorHash})
const
StatusResponse.deserialize(List<int> bytes)
factory
StatusResponse.fromJson(Map<String, dynamic> json)
factory

Properties

appHash List<int>?
block height timestamp
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
earliestStoreHeight BigInt?
final
hashCode int
The hash code for this object.
no setterinherited
height BigInt?
earliest block height available in the store
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp Timestamp?
current block height
final
validatorHash List<int>?
app hash of the current block
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig