InterfaceDescriptor class

InterfaceDescriptor describes the implementation of an interface

Inheritance

Constructors

InterfaceDescriptor({String? fullname, List<InterfaceAcceptingMessageDescriptor> interfaceAcceptingMessages = const [], List<InterfaceImplementerDescriptor> interfaceImplementers = const []})
const
InterfaceDescriptor.deserialize(List<int> bytes)
factory
InterfaceDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
fullname String?
fullname is the name of the interface
final
hashCode int
The hash code for this object.
no setterinherited
interfaceAcceptingMessages List<InterfaceAcceptingMessageDescriptor>
interface_accepting_messages contains information regarding the proto messages which contain the interface as google.protobuf.Any field
final
interfaceImplementers List<InterfaceImplementerDescriptor>
interface_implementers is a list of the descriptors of the interface implementers
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig