InterfaceImplementerDescriptor class
InterfaceImplementerDescriptor describes an interface implementer
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- InterfaceImplementerDescriptor
Constructors
- InterfaceImplementerDescriptor({String? fullname, String? typeUrl})
-
const
-
InterfaceImplementerDescriptor.deserialize(List<
int> bytes) -
factory
-
InterfaceImplementerDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- fullname → String?
-
fullname is the protobuf queryable name of the interface implementer
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeUrl → String?
-
type_url defines the type URL used when marshalling the type as any
this is required so we can provide type safe google.protobuf.Any marshalling and
unmarshalling, making sure that we don't accept just 'any' type
in our interface fields
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig