params property

ConsensusParams? params
final

params are the tendermint consensus params stored in the consensus module. Please note that params.version is not populated in this response, it is tracked separately in the x/upgrade module.

Implementation

final tendermint_types_params.ConsensusParams? params;