QueryValidatorSlashesRequest class

QueryValidatorSlashesRequest is the request type for the Query/ValidatorSlashes RPC method

Inheritance
Mixed-in types

Constructors

QueryValidatorSlashesRequest({String? validatorAddress, BigInt? startingHeight, BigInt? endingHeight, PageRequest? pagination})
const
QueryValidatorSlashesRequest.deserialize(List<int> bytes)
factory
QueryValidatorSlashesRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
endingHeight BigInt?
starting_height defines the optional ending height to query the slashes.
final
hashCode int
The hash code for this object.
no setterinherited
pagination PageRequest?
pagination defines an optional pagination for the request.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startingHeight BigInt?
starting_height defines the optional starting height to query the slashes.
final
validatorAddress String?
validator_address defines the validator address to query for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryValidatorSlashesResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryValidatorSlashesResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig