QueryAccountResponse class

QueryAccountResponse is the response type for the Query/Account RPC method.

Inheritance

Constructors

QueryAccountResponse({String? balance, String? codeHash, BigInt? nonce})
const
QueryAccountResponse.deserialize(List<int> bytes)
factory
QueryAccountResponse.fromJson(Map<String, dynamic> json)
factory

Properties

balance String?
balance is the balance of the EVM denomination.
final
codeHash String?
code_hash is the hex-formatted code bytes from the EOA.
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
nonce BigInt?
nonce is the account's sequence number.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig