QueryParamsResponse class

QueryParamsResponse is the response type for the Query/Params RPC method.

Inheritance

Constructors

QueryParamsResponse({VotingParams? votingParams, DepositParams? depositParams, TallyParams? tallyParams, Params? params})
const
QueryParamsResponse.deserialize(List<int> bytes)
factory
QueryParamsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
depositParams DepositParams?
Deprecated: Prefer to use params instead. deposit_params defines the parameters related to deposit.
final
hashCode int
The hash code for this object.
no setterinherited
params Params?
params defines all the parameters of x/gov module.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tallyParams TallyParams?
Deprecated: Prefer to use params instead. tally_params defines the parameters related to tally.
final
votingParams VotingParams?
Deprecated: Prefer to use params instead. voting_params defines the parameters related to voting.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig