QueryDepositRequest class

QueryDepositRequest is the request type for the Query/Deposit RPC method.

Inheritance
Mixed-in types

Constructors

QueryDepositRequest({BigInt? proposalId, String? depositor})
const
QueryDepositRequest.deserialize(List<int> bytes)
factory
QueryDepositRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
depositor String?
depositor defines the deposit addresses from the proposals.
final
hashCode int
The hash code for this object.
no setterinherited
proposalId BigInt?
proposal_id defines the unique id of the proposal.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryDepositResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryDepositResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig