QueryProposalsRequest class
QueryProposalsRequest is the request type for the Query/Proposals RPC method.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryProposalsRequest
- Mixed-in types
Constructors
- QueryProposalsRequest({ProposalStatus? proposalStatus, String? voter, String? depositor, PageRequest? pagination})
-
const
-
QueryProposalsRequest.deserialize(List<
int> bytes) -
factory
-
QueryProposalsRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- depositor → String?
-
depositor defines the deposit addresses from the proposals.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pagination → PageRequest?
-
pagination defines an optional pagination for the request.
final
- proposalStatus → ProposalStatus?
-
proposal_status defines the status of the proposals.
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voter → String?
-
voter defines the voter address for the proposals.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onQueryResponse(
List< int> bytes) → QueryProposalsResponse -
override
-
onQueryResponseJson(
Map< String, dynamic> json) → QueryProposalsResponse -
override
-
protoConfig(
) → ProtoMessageConfig -
override
-
requestSpec(
) → HttpRequestSpec -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig