continuousFund property
ContinuousFunds is the given continuous fund returned in the query.
Implementation
final cosmos_protocolpool_v1_types.ContinuousFund? continuousFund;
ContinuousFunds is the given continuous fund returned in the query.
final cosmos_protocolpool_v1_types.ContinuousFund? continuousFund;