MsgCommunityPoolSpend class

MsgCommunityPoolSpend defines a message for sending tokens from the community pool to another account. This message is typically executed via a governance proposal with the governance module being the executing authority.

Inheritance
Mixed-in types

Constructors

MsgCommunityPoolSpend({String? authority, String? recipient, List<Coin> amount = const []})
const
MsgCommunityPoolSpend.deserialize(List<int> bytes)
factory
MsgCommunityPoolSpend.fromJson(Map<String, dynamic> json)
factory

Properties

amount List<Coin>
final
authority String?
Authority is the address that controls the module (defaults to x/gov unless overwritten).
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
recipient String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCommunityPoolSpendResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCommunityPoolSpendResponse
override
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig