MsgCreateContinuousFund class

MsgCreateContinuousFund defines a message for adding continuous funds.

Inheritance
Mixed-in types

Constructors

MsgCreateContinuousFund({String? authority, String? recipient, String? percentage, Timestamp? expiry})
const
MsgCreateContinuousFund.deserialize(List<int> bytes)
factory
MsgCreateContinuousFund.fromJson(Map<String, dynamic> json)
factory

Properties

authority String?
Authority is the address that controls the module (defaults to x/gov unless overwritten).
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
expiry Timestamp?
Optional, if expiry is set, removes the state object when expired.
final
hashCode int
The hash code for this object.
no setterinherited
percentage String?
Percentage is the percentage of funds to be allocated from Community pool.
final
protoValues List<Object?>
no setteroverride
recipient String?
Recipient address of the account receiving funds.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateContinuousFundResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateContinuousFundResponse
override
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig