authority property
Authority is the address that controls the module (defaults to x/gov unless overwritten).
Implementation
final String? authority;
Authority is the address that controls the module (defaults to x/gov unless overwritten).
final String? authority;