QueryDelegatorValidatorsRequest class

QueryDelegatorValidatorsRequest is request type for the Query/DelegatorValidators RPC method.

Inheritance
Mixed-in types

Constructors

QueryDelegatorValidatorsRequest({String? delegatorAddr, PageRequest? pagination})
const
QueryDelegatorValidatorsRequest.deserialize(List<int> bytes)
factory
QueryDelegatorValidatorsRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
delegatorAddr String?
delegator_addr defines the delegator address to query for.
final
hashCode int
The hash code for this object.
no setterinherited
pagination PageRequest?
pagination defines an optional pagination for the request.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryDelegatorValidatorsResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryDelegatorValidatorsResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig