QueryModuleVersionsRequest class
QueryModuleVersionsRequest is the request type for the Query/ModuleVersions RPC method.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryModuleVersionsRequest
- Mixed-in types
Constructors
- QueryModuleVersionsRequest({String? moduleName})
-
const
-
QueryModuleVersionsRequest.deserialize(List<
int> bytes) -
factory
-
QueryModuleVersionsRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- moduleName → String?
-
module_name is a field to query a specific module
consensus version from state. Leaving this empty will
fetch the full list of module versions from state
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onQueryResponse(
List< int> bytes) → QueryModuleVersionsResponse -
override
-
onQueryResponseJson(
Map< String, dynamic> json) → QueryModuleVersionsResponse -
override
-
protoConfig(
) → ProtoMessageConfig -
override
-
requestSpec(
) → HttpRequestSpec -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig