QueryBuildAddressRequest class

QueryBuildAddressRequest is the request type for the Query/BuildAddress RPC method.

Inheritance
Mixed-in types

Constructors

QueryBuildAddressRequest({String? codeHash, String? creatorAddress, String? salt, List<int>? initArgs})
const
QueryBuildAddressRequest.deserialize(List<int> bytes)
factory
QueryBuildAddressRequest.fromJson(Map<String, dynamic> json)
factory

Properties

codeHash String?
CodeHash is the hash of the code
final
creatorAddress String?
CreatorAddress is the address of the contract instantiator
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
initArgs List<int>?
InitArgs are optional json encoded init args to be used in contract address building if provided
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt String?
Salt is a hex encoded salt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryBuildAddressResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryBuildAddressResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig