QueryContractsByCodeResponse class

QueryContractsByCodeResponse is the response type for the Query/ContractsByCode RPC method

Inheritance

Constructors

QueryContractsByCodeResponse({List<String> contracts = const [], PageResponse? pagination})
const
QueryContractsByCodeResponse.deserialize(List<int> bytes)
factory
QueryContractsByCodeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

contracts List<String>
contracts are a set of contract addresses
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
pagination PageResponse?
pagination defines the pagination in the response.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig