MsgStoreCode class

MsgStoreCode submit Wasm code to the system

Inheritance
Mixed-in types

Constructors

MsgStoreCode({String? sender, List<int>? wasmByteCode, AccessConfig? instantiatePermission})
const
MsgStoreCode.deserialize(List<int> bytes)
factory
MsgStoreCode.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
instantiatePermission AccessConfig?
Used in v1beta1 InstantiatePermission access control to apply on contract creation, optional
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String?
Sender is the actor that signed the messages
final
wasmByteCode List<int>?
WASMByteCode can be raw or gzip compressed
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgStoreCodeResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgStoreCodeResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig