AccessControl class

AccessControl defines the permission policy of the EVM for creating and calling contracts

Inheritance

Constructors

AccessControl({AccessControlType? create, AccessControlType? call})
const
AccessControl.deserialize(List<int> bytes)
factory
AccessControl.fromJson(Map<String, dynamic> json)
factory

Properties

call AccessControlType?
call defines the permission policy for calling contracts
final
create AccessControlType?
create defines the permission policy for creating contracts
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig