ChainConfig class
ChainConfig defines the Ethereum ChainConfig parameters using *sdk.Int values instead of *big.Int.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- ChainConfig
Constructors
- ChainConfig({String? homesteadBlock, String? daoForkBlock, bool? daoForkSupport, String? eip150Block, String? eip150Hash, String? eip155Block, String? eip158Block, String? byzantiumBlock, String? constantinopleBlock, String? petersburgBlock, String? istanbulBlock, String? muirGlacierBlock, String? berlinBlock, String? londonBlock, String? arrowGlacierBlock, String? grayGlacierBlock, String? mergeNetsplitBlock, String? shanghaiBlock, String? cancunBlock, BigInt? chainId, String? denom, BigInt? decimals})
-
const
-
ChainConfig.deserialize(List<
int> bytes) -
factory
-
ChainConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- arrowGlacierBlock → String?
-
arrow_glacier_block: Eip-4345 (bomb delay) switch block (nil = no fork, 0 = already activated)
final
- berlinBlock → String?
-
berlin_block: Berlin switch block (nil = no fork, 0 = already on berlin)
final
- byzantiumBlock → String?
-
byzantium_block: Byzantium switch block (nil no fork, 0 = already on byzantium)
final
- cancunBlock → String?
-
cancun_block switch block (nil = no fork, 0 = already on cancun)
final
- chainId → BigInt?
-
chain_id is the id of the chain (EIP-155)
final
- constantinopleBlock → String?
-
constantinople_block: Constantinople switch block (nil no fork, 0 = already activated)
final
- daoForkBlock → String?
-
dao_fork_block corresponds to TheDAO hard-fork switch block (nil no fork)
final
- daoForkSupport → bool?
-
dao_fork_support defines whether the nodes supports or opposes the DAO hard-fork
final
- decimals → BigInt?
-
decimals is the real decimal precision of the denomination used on the EVM
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- denom → String?
-
denom is the denomination used on the EVM
final
- eip150Block → String?
-
eip150_block: EIP150 implements the Gas price changes
(https://github.com/ethereum/EIPs/issues/150) EIP150 HF block (nil no fork)
final
- eip150Hash → String?
-
eip150_hash: EIP150 HF hash (needed for header only clients as only gas pricing changed)
final
- eip155Block → String?
-
eip155_block: EIP155Block HF block
final
- eip158Block → String?
-
eip158_block: EIP158 HF block
final
- grayGlacierBlock → String?
-
DEPRECATED: merge fork block was deprecated: https://github.com/ethereum/go-ethereum/pull/24904
gray_glacier_block: EIP-5133 (bomb delay) switch block (nil = no fork, 0 = already activated)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- homesteadBlock → String?
-
homestead_block switch (nil no fork, 0 = already homestead)
final
- istanbulBlock → String?
-
istanbul_block: Istanbul switch block (nil no fork, 0 = already on istanbul)
final
- londonBlock → String?
-
DEPRECATED: EWASM, YOLOV3 and Catalyst block have been deprecated
london_block: London switch block (nil = no fork, 0 = already on london)
final
- mergeNetsplitBlock → String?
-
merge_netsplit_block: Virtual fork after The Merge to use as a network splitter
final
- muirGlacierBlock → String?
-
muir_glacier_block: Eip-2384 (bomb delay) switch block (nil no fork, 0 = already activated)
final
- petersburgBlock → String?
-
petersburg_block: Petersburg switch block (nil same as Constantinople)
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shanghaiBlock → String?
-
shanghai_block switch block (nil = no fork, 0 = already on shanghai)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig