eip150Hash property
eip150_hash: EIP150 HF hash (needed for header only clients as only gas pricing changed)
Implementation
final String? eip150Hash;
eip150_hash: EIP150 HF hash (needed for header only clients as only gas pricing changed)
final String? eip150Hash;