proto_messages/ethermint/evm/v1/src/query library

Classes

EstimateGasResponse
EstimateGasResponse defines EstimateGas response
EthCallRequest
EthCallRequest defines EthCall request
QueryAccountRequest
QueryAccountRequest is the request type for the Query/Account RPC method.
QueryAccountResponse
QueryAccountResponse is the response type for the Query/Account RPC method.
QueryBalanceRequest
QueryBalanceRequest is the request type for the Query/Balance RPC method.
QueryBalanceResponse
QueryBalanceResponse is the response type for the Query/Balance RPC method.
QueryBaseFeeRequest
QueryBaseFeeRequest defines the request type for querying the EIP1559 base fee.
QueryBaseFeeResponse
QueryBaseFeeResponse returns the EIP1559 base fee.
QueryCodeRequest
QueryCodeRequest is the request type for the Query/Code RPC method.
QueryCodeResponse
QueryCodeResponse is the response type for the Query/Code RPC method.
QueryConfigRequest
QueryConfigRequest defines the request type for querying the Config
QueryConfigResponse
QueryConfigResponse returns the EVM Config.
QueryCosmosAccountRequest
QueryCosmosAccountRequest is the request type for the Query/CosmosAccount RPC method.
QueryCosmosAccountResponse
QueryCosmosAccountResponse is the response type for the Query/CosmosAccount RPC method.
QueryGlobalMinGasPriceRequest
QueryGlobalMinGasPriceRequest defines the request type for querying the GlobalMinGasPrice
QueryGlobalMinGasPriceResponse
QueryGlobalMinGasPriceResponse returns the GlobalMinGasPrice.
QueryParamsRequest
QueryParamsRequest defines the request type for querying x/evm parameters.
QueryParamsResponse
QueryParamsResponse defines the response type for querying x/evm parameters.
QueryStorageRequest
QueryStorageRequest is the request type for the Query/Storage RPC method.
QueryStorageResponse
QueryStorageResponse is the response type for the Query/Storage RPC method.
QueryTraceBlockRequest
QueryTraceBlockRequest defines TraceTx request
QueryTraceBlockResponse
QueryTraceBlockResponse defines TraceBlock response
QueryTraceTxRequest
QueryTraceTxRequest defines TraceTx request
QueryTraceTxResponse
QueryTraceTxResponse defines TraceTx response
QueryValidatorAccountRequest
QueryValidatorAccountRequest is the request type for the Query/ValidatorAccount RPC method.
QueryValidatorAccountResponse
QueryValidatorAccountResponse is the response type for the Query/ValidatorAccount RPC method.