QueryCosmosAccountResponse class

QueryCosmosAccountResponse is the response type for the Query/CosmosAccount RPC method.

Inheritance

Constructors

QueryCosmosAccountResponse({String? cosmosAddress, BigInt? sequence, BigInt? accountNumber})
const
QueryCosmosAccountResponse.deserialize(List<int> bytes)
factory
QueryCosmosAccountResponse.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumber BigInt?
account_number is the account number
final
cosmosAddress String?
cosmos_address is the cosmos address of the account.
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence BigInt?
sequence is the account's sequence number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig