QueryTraceTxRequest class

QueryTraceTxRequest defines TraceTx request

Inheritance
Mixed-in types

Constructors

QueryTraceTxRequest({MsgEthereumTx? msg, TraceConfig? traceConfig, List<MsgEthereumTx> predecessors = const [], BigInt? blockNumber, String? blockHash, Timestamp? blockTime, List<int>? proposerAddress, BigInt? chainId, BigInt? blockMaxGas})
const
QueryTraceTxRequest.deserialize(List<int> bytes)
factory
QueryTraceTxRequest.fromJson(Map<String, dynamic> json)
factory

Properties

blockHash String?
block_hash of requested transaction
final
blockMaxGas BigInt?
block_max_gas of the block of the requested transaction
final
blockNumber BigInt?
block_number of requested transaction
final
blockTime Timestamp?
block_time of requested transaction
final
chainId BigInt?
chain_id is the eip155 chain id parsed from the requested block header
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
msg MsgEthereumTx?
msg is the MsgEthereumTx for the requested transaction
final
predecessors List<MsgEthereumTx>
predecessors is an array of transactions included in the same block need to be replayed first to get correct context for tracing.
final
proposerAddress List<int>?
proposer_address is the proposer of the requested block
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
traceConfig TraceConfig?
tx_index is not necessary anymore trace_config holds extra parameters to trace functions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryTraceTxResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryTraceTxResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig