token property
token identifier can be either the hex contract address of the ERC20 or the Cosmos base denomination
Implementation
final String? token;
token identifier can be either the hex contract address of the ERC20 or the Cosmos base denomination
final String? token;