proto_messages/google/protobuf/models library

Classes

DescriptorProto
Describes a message type.
DescriptorProtoExtensionRange
DescriptorProtoReservedRange
Range of reserved tag numbers. Reserved tag numbers may not be used by fields or extension ranges in the same message. Reserved ranges may not overlap.
Duration
Protocol Buffers - Google's data interchange format Copyright 2008 Google Inc. All rights reserved. https://developers.google.com/protocol-buffers/
Empty
Protocol Buffers - Google's data interchange format Copyright 2008 Google Inc. All rights reserved. https://developers.google.com/protocol-buffers/
EnumDescriptorProto
Describes an enum type.
EnumDescriptorProtoEnumReservedRange
Range of reserved numeric values. Reserved values may not be used by entries in the same enum. Reserved ranges may not overlap.
EnumOptions
Clients can define custom options in extensions of this message. See above.
EnumValueDescriptorProto
Describes a value within an enum.
EnumValueOptions
Clients can define custom options in extensions of this message. See above.
ExtensionRangeOptions
ExtensionRangeOptionsDeclaration
FeatureSet
=================================================================== Features not well scoped. This means that each of the feature enums below can clash with each other. The short names we've chosen maximize call-site readability, but leave us very open to this scenario. A future feature will be designed and implemented to handle this, hopefully before we ever hit a conflict here.
FieldDescriptorProto
Clients can define custom options in extensions of this message. See above. Describes a field within a message.
FieldOptions
Clients can define custom options in extensions of this message. See above.
FieldOptionsEditionDefault
FieldOptionsFeatureSupport
Information about the support window of a feature.
FileDescriptorProto
Describes a complete .proto file.
FileOptions
=================================================================== Options Each of the definitions above may have "options" attached. These are just annotations which may cause code to be generated slightly differently or may contain hints for code that manipulates protocol messages.
MessageOptions
Clients can define custom options in extensions of this message. See the documentation for the "Options" section above.
MethodDescriptorProto
Describes a method of a service.
MethodOptions
Clients can define custom options in extensions of this message. See above.
OneofDescriptorProto
Describes a oneof.
OneofOptions
Clients can define custom options in extensions of this message. See above. removed jtype reserve target, target_obsolete_do_not_use
ServiceDescriptorProto
Describes a service.
ServiceOptions
Clients can define custom options in extensions of this message. See above.
SourceCodeInfo
=================================================================== Optional source code info Encapsulates information about the original source file from which a FileDescriptorProto was generated.
SourceCodeInfoLocation
Timestamp
Protocol Buffers - Google's data interchange format Copyright 2008 Google Inc. All rights reserved. https://developers.google.com/protocol-buffers/
UninterpretedOption
Clients can define custom options in extensions of this message. See above. A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.
UninterpretedOptionNamePart
The name of the uninterpreted option. Each string represents a segment in a dot-separated name. is_extension is true iff a segment represents an extension (denoted with parentheses in options specs in .proto files). E.g.,{ "foo", false, "bar.baz", true, "moo", false } represents "foo.(bar.baz).moo".

Enums

Edition
Extensions for tooling. The full set of known editions.
ExtensionRangeOptionsVerificationState
The verification state of the extension range.
FeatureSetEnforceNamingStyle
FeatureSetEnumType
FeatureSetFieldPresence
FeatureSetJsonFormat
FeatureSetMessageEncoding
FeatureSetRepeatedFieldEncoding
FeatureSetUtf8Validation
FeatureSetVisibilityFeatureDefaultSymbolVisibility
FieldDescriptorProtoLabel
Uses ZigZag encoding.
FieldDescriptorProtoType
FieldOptionsCType
deprecated = true,
FieldOptionsJSType
FieldOptionsOptionRetention
If set to RETENTION_SOURCE, the option will be omitted from the binary.
FieldOptionsOptionTargetType
This indicates the types of entities that the field may apply to when used as an option. If it is unset, then the field may be freely used as an option on any kind of entity.
FileOptionsOptimizeMode
Generated classes can be optimized for speed or code size.
MethodOptionsIdempotencyLevel
Is this method side-effect-free (or safe in HTTP parlance), or idempotent, or neither? HTTP based RPC implementation may choose GET verb for safe methods, and PUT verb for idempotent methods instead of the default POST.
SymbolVisibility
Describes the 'visibility' of a symbol with respect to the proto import system. Symbols can only be imported when the visibility rules do not prevent it (ex: local symbols cannot be imported). Visibility modifiers can only set on message and enum as they are the only types available to be referenced from other files.