ExtensionRangeOptions class

Inheritance

Constructors

ExtensionRangeOptions({List<UninterpretedOption> uninterpretedOption = const [], List<ExtensionRangeOptionsDeclaration> declaration = const [], FeatureSet? features, ExtensionRangeOptionsVerificationState? verification})
const
ExtensionRangeOptions.deserialize(List<int> bytes)
factory
ExtensionRangeOptions.fromJson(Map<String, dynamic> json)
factory

Properties

declaration List<ExtensionRangeOptionsDeclaration>
removed is_repeated For external users: DO NOT USE. We are in the process of open sourcing extension declaration and executing internal cleanups before it can be used externally.
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
features FeatureSet?
Any features defined in the specific edition.
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uninterpretedOption List<UninterpretedOption>
The parser stores options it doesn't recognize here. See above.
final
verification ExtensionRangeOptionsVerificationState?
The verification state of the range. are marked as UNVERIFIED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig