declaration property

removed is_repeated For external users: DO NOT USE. We are in the process of open sourcing extension declaration and executing internal cleanups before it can be used externally.

Implementation

final List<ExtensionRangeOptionsDeclaration> declaration;