ExtensionRangeOptionsVerificationState enum
The verification state of the extension range.
Values
- declaration → const ExtensionRangeOptionsVerificationState
-
All the extensions of the range must be declared.
const ExtensionRangeOptionsVerificationState(0, 'DECLARATION') - unverified → const ExtensionRangeOptionsVerificationState
-
const ExtensionRangeOptionsVerificationState(1, 'UNVERIFIED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - protoName → String
-
The original proto identifier, e.g. "VOTE_OPTION_UNSPECIFIED".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The original proto wire value for this enum constant.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from(
Object? value) → ExtensionRangeOptionsVerificationState -
Looks up a value by wire int, Dart enum name, or original proto
name (whichever
valuehappens to be). Throws if not found. -
fromValue(
int? value) → ExtensionRangeOptionsVerificationState - Looks up a value by its proto wire int. Throws if not found.
Constants
-
values
→ const List<
ExtensionRangeOptionsVerificationState> - A constant List of the values in this enum, in order of their declaration.