debugRedact property
Indicate that the field value should not be printed out when using debug formats, e.g. when the field contains sensitive credentials.
Implementation
final bool? debugRedact;
Indicate that the field value should not be printed out when using debug formats, e.g. when the field contains sensitive credentials.
final bool? debugRedact;