FieldOptionsFeatureSupport class

Information about the support window of a feature.

Inheritance

Constructors

FieldOptionsFeatureSupport({Edition? editionIntroduced, Edition? editionDeprecated, String? deprecationWarning, Edition? editionRemoved})
const
FieldOptionsFeatureSupport.deserialize(List<int> bytes)
factory
FieldOptionsFeatureSupport.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
deprecationWarning String?
The deprecation warning text if this feature is used after the edition it was marked deprecated in.
final
editionDeprecated Edition?
The edition this feature becomes deprecated in. Using this after this edition may trigger warnings.
final
editionIntroduced Edition?
The edition that this feature was first available in. In editions earlier than this one, the default assigned to EDITION_LEGACY will be used, and proto files will not be able to override it.
final
editionRemoved Edition?
The edition this feature is no longer available in. In editions after this one, the last default assigned will be used, and proto files will not be able to override it.
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig