editionIntroduced property

Edition? editionIntroduced
final

The edition that this feature was first available in. In editions earlier than this one, the default assigned to EDITION_LEGACY will be used, and proto files will not be able to override it.

Implementation

final Edition? editionIntroduced;