editionRemoved property

Edition? editionRemoved
final

The edition this feature is no longer available in. In editions after this one, the last default assigned will be used, and proto files will not be able to override it.

Implementation

final Edition? editionRemoved;