sourceCodeInfo property

SourceCodeInfo? sourceCodeInfo
final

This field contains optional information about the original source code. You may safely remove this entire field without harming runtime functionality of the descriptors -- the information is needed only by development tools.

Implementation

final SourceCodeInfo? sourceCodeInfo;