ccEnableArenas property
Enables the use of arenas for the proto messages in this file. This applies only to generated classes for C++.
Implementation
final bool? ccEnableArenas;
Enables the use of arenas for the proto messages in this file. This applies only to generated classes for C++.
final bool? ccEnableArenas;