phpClassPrefix property
Sets the php class prefix which is prepended to all php generated classes from this .proto. Default is empty.
Implementation
final String? phpClassPrefix;
Sets the php class prefix which is prepended to all php generated classes from this .proto. Default is empty.
final String? phpClassPrefix;