phpMetadataNamespace property

String? phpMetadataNamespace
final

Use this option to change the namespace of php generated metadata classes. Default is empty. When this option is empty, the proto file name will be used for determining the namespace.

Implementation

final String? phpMetadataNamespace;