rubyPackage property

String? rubyPackage
final

Use this option to change the package of ruby generated classes. Default is empty. When this option is not set, the package name will be used for determining the ruby package.

Implementation

final String? rubyPackage;