swiftPrefix property

String? swiftPrefix
final

By default Swift generators will take the proto package and CamelCase it replacing '.' with underscore and use that to prefix the types/symbols defined. When this options is provided, they will use this value instead to prefix the types/symbols defined.

Implementation

final String? swiftPrefix;