FileOptionsOptimizeMode enum

Generated classes can be optimized for speed or code size.

Inheritance
Available extensions

Values

speed → const FileOptionsOptimizeMode
const FileOptionsOptimizeMode(1, 'SPEED')
codeSize → const FileOptionsOptimizeMode

Generate complete code for parsing, serialization, etc.

const FileOptionsOptimizeMode(2, 'CODE_SIZE')
liteRuntime → const FileOptionsOptimizeMode

Use ReflectionOps to implement these methods.

const FileOptionsOptimizeMode(3, 'LITE_RUNTIME')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
protoName String
The original proto identifier, e.g. "VOTE_OPTION_UNSPECIFIED".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The original proto wire value for this enum constant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(Object? value) FileOptionsOptimizeMode
Looks up a value by wire int, Dart enum name, or original proto name (whichever value happens to be). Throws if not found.
fromValue(int? value) FileOptionsOptimizeMode
Looks up a value by its proto wire int. Throws if not found.

Constants

values → const List<FileOptionsOptimizeMode>
A constant List of the values in this enum, in order of their declaration.