MessageOptions class
Clients can define custom options in extensions of this message. See the documentation for the "Options" section above.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- MessageOptions
Constructors
-
MessageOptions({bool? messageSetWireFormat, bool? noStandardDescriptorAccessor, bool? deprecated, bool? mapEntry, bool? deprecatedLegacyJsonFieldConflicts, FeatureSet? features, List<
UninterpretedOption> uninterpretedOption = const []}) -
const
-
MessageOptions.deserialize(List<
int> bytes) -
factory
-
MessageOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- deprecated → bool?
-
Is this message deprecated?
Depending on the target platform, this can emit Deprecated annotations
for the message, or it will be completely ignored; in the very least,
this is a formalization for deprecating messages.
final
- deprecatedLegacyJsonFieldConflicts → bool?
-
javalite_serializable
javanano_as_lite
Enable the legacy handling of JSON field name conflicts. This lowercases
and strips underscored from the fields before comparison in proto3 only.
The new behavior takes
json_nameinto account and applies to proto2 as well.final - features → FeatureSet?
-
Any features defined in the specific edition.
WARNING: This field should only be used by protobuf plugins or special
cases like the proto compiler. Other uses are discouraged and
developers should rely on the protoreflect APIs for their client language.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapEntry → bool?
-
Whether the message is an automatically generated map entry type for the
maps field.
final
- messageSetWireFormat → bool?
-
Set true to use the old proto1 MessageSet wire format for extensions.
This is provided for backwards-compatibility with the MessageSet wire
format. You should not use this for any other reason: It's less
efficient, has fewer features, and is more complicated.
final
- noStandardDescriptorAccessor → bool?
-
Disables the generation of the standard "descriptor()" accessor, which can
conflict with a field of the same name. This is meant to make migration
from proto1 easier; new code should avoid fields named "descriptor".
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uninterpretedOption
→ List<
UninterpretedOption> -
The parser stores options it doesn't recognize here. See above.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig