MethodDescriptorProto class

Describes a method of a service.

Inheritance

Constructors

MethodDescriptorProto({String? name, String? inputType, String? outputType, MethodOptions? options, bool? clientStreaming, bool? serverStreaming})
const
MethodDescriptorProto.deserialize(List<int> bytes)
factory
MethodDescriptorProto.fromJson(Map<String, dynamic> json)
factory

Properties

clientStreaming bool?
Identifies if client streams multiple client messages
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
inputType String?
Input and output type names. These are resolved in the same way as FieldDescriptorProto.type_name, but must refer to a message type.
final
name String?
final
options MethodOptions?
final
outputType String?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverStreaming bool?
Identifies if server streams multiple server messages
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig