MethodOptions class

Clients can define custom options in extensions of this message. See above.

Inheritance

Constructors

MethodOptions({bool? deprecated, MethodOptionsIdempotencyLevel? idempotencyLevel, FeatureSet? features, List<UninterpretedOption> uninterpretedOption = const []})
const
MethodOptions.deserialize(List<int> bytes)
factory
MethodOptions.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
deprecated bool?
Note: Field numbers 1 through 32 are reserved for Google's internal RPC framework. We apologize for hoarding these numbers to ourselves, but we were already using them long before we decided to release Protocol Buffers. Is this method deprecated? Depending on the target platform, this can emit Deprecated annotations for the method, or it will be completely ignored; in the very least, this is a formalization for deprecating methods.
final
features FeatureSet?
Any features defined in the specific edition. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.
final
hashCode int
The hash code for this object.
no setterinherited
idempotencyLevel MethodOptionsIdempotencyLevel?
idempotent, but may have side effects
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uninterpretedOption List<UninterpretedOption>
The parser stores options it doesn't recognize here. See above.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig