UninterpretedOptionNamePart class
The name of the uninterpreted option. Each string represents a segment in
a dot-separated name. is_extension is true iff a segment represents an
extension (denoted with parentheses in options specs in .proto files).
E.g.,{ "foo", false, "bar.baz", true, "moo", false } represents
"foo.(bar.baz).moo".
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- UninterpretedOptionNamePart
Constructors
- UninterpretedOptionNamePart({required String namePart, bool isExtension = false})
-
const
-
UninterpretedOptionNamePart.deserialize(List<
int> bytes) -
factory
-
UninterpretedOptionNamePart.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExtension → bool
-
final
- namePart → String
-
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig