QueryEscrowAddressRequest class

QueryEscrowAddressRequest is the request type for the EscrowAddress RPC method.

Inheritance
Mixed-in types

Constructors

QueryEscrowAddressRequest({String? portId, String? channelId})
const
QueryEscrowAddressRequest.deserialize(List<int> bytes)
factory
QueryEscrowAddressRequest.fromJson(Map<String, dynamic> json)
factory

Properties

channelId String?
unique channel identifier
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
portId String?
unique port identifier
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryEscrowAddressResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryEscrowAddressResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig