startingHeight property
starting_height defines the optional starting height to query the slashes.
Implementation
final BigInt? startingHeight;
starting_height defines the optional starting height to query the slashes.
final BigInt? startingHeight;