QueryResourceRequest class

QueryResourceRequest is the request type for the Query/Resource RPC method

Inheritance
Mixed-in types

Constructors

QueryResourceRequest({String? address, String? structTag})
const
QueryResourceRequest.deserialize(List<int> bytes)
factory
QueryResourceRequest.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
address is the owner address of the module to query
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structTag String?
struct_tag is the unique identifier of the resource to query
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryResourceResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryResourceResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig