QueryResourcesRequest class

QueryResourcesRequest is the request type for the Query/Resources RPC method

Inheritance
Mixed-in types

Constructors

QueryResourcesRequest({String? address, PageRequest? pagination})
const
QueryResourcesRequest.deserialize(List<int> bytes)
factory
QueryResourcesRequest.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
address is the owner address of the module to query
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
pagination PageRequest?
pagination defines an optional pagination for the request.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryResourcesResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryResourcesResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig