QueryViewRequest class

QueryViewRequest is the request type for the QueryView RPC method

Inheritance
Mixed-in types

Constructors

QueryViewRequest({String? address, String? moduleName, String? functionName, List<String> typeArgs = const [], List<List<int>> args = const []})
const
QueryViewRequest.deserialize(List<int> bytes)
factory
QueryViewRequest.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
Address is the owner address of the module to query
final
args List<List<int>>
Args is the arguments of a function to execute
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
functionName String?
FunctionName is the name of a function to query
final
hashCode int
The hash code for this object.
no setterinherited
moduleName String?
ModuleName is the module name of the entry function to query
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeArgs List<String>
TypeArgs is the type arguments of a function to execute ex) "0x1::BasicCoin::Initia", "bool", "u8", "u64"
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryViewResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryViewResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig