authority property
authority is the address that controls the module (defaults to x/gov unless overwritten).
Implementation
final String? authority;
authority is the address that controls the module (defaults to x/gov unless overwritten).
final String? authority;