MsgScriptJSON class

MsgScriptJSON is the message to execute script code with sender as signer

Inheritance
Mixed-in types

Constructors

MsgScriptJSON({String? sender, List<int>? codeBytes, List<String> typeArgs = const [], List<String> args = const []})
const
MsgScriptJSON.deserialize(List<int> bytes)
factory
MsgScriptJSON.fromJson(Map<String, dynamic> json)
factory

Properties

args List<String>
Args is the arguments of a function to execute in json stringify format
final
codeBytes List<int>?
CodeBytes is the script bytes code to execute
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String?
Sender is the that actor that signed the messages
final
typeArgs List<String>
TypeArgs is the type arguments of a function to execute ex) "0x1::BasicCoin::Initia", "bool", "u8", "u64"
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgScriptJSONResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgScriptJSONResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig