QueryRedelegationsResponse class

QueryRedelegationsResponse is response type for the Query/Redelegations RPC method.

Inheritance

Constructors

QueryRedelegationsResponse({List<RedelegationResponse> redelegationResponses = const [], PageResponse? pagination})
const
QueryRedelegationsResponse.deserialize(List<int> bytes)
factory
QueryRedelegationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
pagination PageResponse?
pagination defines the pagination in the response.
final
protoValues List<Object?>
no setteroverride
redelegationResponses List<RedelegationResponse>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig