QueryStorageRequest class

QueryStorageRequest is the request type for the Query/Storage RPC method.

Inheritance
Mixed-in types

Constructors

QueryStorageRequest({String? address, String? key})
const
QueryStorageRequest.deserialize(List<int> bytes)
factory
QueryStorageRequest.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
address is the ethereum hex address to query the storage state for.
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
key String?
key defines the key of the storage state
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryStorageResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryStorageResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig