QueryDerivativeOrderbookRequest class

QueryDerivativeOrderbookRequest is the request type for the Query/DerivativeOrderbook RPC method.

Inheritance
Mixed-in types

Constructors

QueryDerivativeOrderbookRequest({String? marketId, BigInt? limit, String? limitCumulativeNotional})
const
QueryDerivativeOrderbookRequest.deserialize(List<int> bytes)
factory
QueryDerivativeOrderbookRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
limit BigInt?
final
limitCumulativeNotional String?
final
marketId String?
Market ID for the market
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryDerivativeOrderbookResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryDerivativeOrderbookResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig