QueryFullSpotMarketRequest class

QuerySpotMarketRequest is the request type for the Query/SpotMarket RPC method.

Inheritance
Mixed-in types

Constructors

QueryFullSpotMarketRequest({String? marketId, bool? withMidPriceAndTob})
const
QueryFullSpotMarketRequest.deserialize(List<int> bytes)
factory
QueryFullSpotMarketRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
marketId String?
Market ID for the market
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
withMidPriceAndTob bool?
Flag to return the markets mid price and top of the book buy and sell orders.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryFullSpotMarketResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryFullSpotMarketResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig