QueryMarketVolatilityResponse class

QueryMarketVolatilityResponse is the response type for the Query/MarketVolatility RPC method.

Inheritance

Constructors

QueryMarketVolatilityResponse({String? volatility, MetadataStatistics? historyMetadata, List<TradeRecord> rawHistory = const []})
const
QueryMarketVolatilityResponse.deserialize(List<int> bytes)
factory
QueryMarketVolatilityResponse.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
historyMetadata MetadataStatistics?
final
protoValues List<Object?>
no setteroverride
rawHistory List<TradeRecord>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
volatility String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig