QuerySpotOrderbookRequest class

QuerySpotOrderbookRequest is the request type for the Query/SpotOrderbook RPC method.

Inheritance
Mixed-in types

Constructors

QuerySpotOrderbookRequest({String? marketId, BigInt? limit, OrderSide? orderSide, String? limitCumulativeNotional, String? limitCumulativeQuantity})
const
QuerySpotOrderbookRequest.deserialize(List<int> bytes)
factory
QuerySpotOrderbookRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
limit BigInt?
the maximum number of orderbook entries to return per side (optional)
final
limitCumulativeNotional String?
limits the number of entries to return per side based on the cumulative notional (in human readable format)
final
limitCumulativeQuantity String?
limits the number of entries to return per side based on the cumulative quantity (in human readable format)
final
marketId String?
Market ID for the market
final
orderSide OrderSide?
the order side to return the orderbook entries for (optional)
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QuerySpotOrderbookResponse
override
onQueryResponseJson(Map<String, dynamic> json) QuerySpotOrderbookResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig