QueryOraclePriceRequest class

QueryOraclePriceRequest is the request type for the Query/OraclePrice RPC method.

Inheritance
Mixed-in types

Constructors

QueryOraclePriceRequest({OracleType? oracleType, String? base, String? quote, ScalingOptions? scalingOptions})
const
QueryOraclePriceRequest.deserialize(List<int> bytes)
factory
QueryOraclePriceRequest.fromJson(Map<String, dynamic> json)
factory

Properties

base String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
oracleType OracleType?
final
protoValues List<Object?>
no setteroverride
quote String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalingOptions ScalingOptions?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryOraclePriceResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryOraclePriceResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig