QueryRoleManagerRequest class

QueryRoleManagerRequest is the request type for the Query/RoleManager RPC method.

Inheritance
Mixed-in types

Constructors

QueryRoleManagerRequest({String? denom, String? manager})
const
QueryRoleManagerRequest.deserialize(List<int> bytes)
factory
QueryRoleManagerRequest.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
denom String?
The token denom
final
hashCode int
The hash code for this object.
no setterinherited
manager String?
The manager Injective address
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryRoleManagerResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryRoleManagerResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig