ConditionalOrderTriggerFailureUpdate class

Inheritance

Constructors

ConditionalOrderTriggerFailureUpdate({String? marketId, String? subaccountId, String? markPrice, String? orderHash, String? cid, String? errorDescription})
const
ConditionalOrderTriggerFailureUpdate.deserialize(List<int> bytes)
factory
ConditionalOrderTriggerFailureUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

cid String?
the client order ID
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
errorDescription String?
the error code
final
hashCode int
The hash code for this object.
no setterinherited
marketId String?
the market ID
final
markPrice String?
the mark price
final
orderHash String?
the order hash
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subaccountId String?
the subaccount ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig