DerivativeOrderUpdate class

Inheritance

Constructors

DerivativeOrderUpdate({OrderUpdateStatus? status, String? orderHash, String? cid, DerivativeOrder? order})
const
DerivativeOrderUpdate.deserialize(List<int> bytes)
factory
DerivativeOrderUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

cid String?
the client order ID
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
order DerivativeOrder?
the order details
final
orderHash String?
the order hash
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status OrderUpdateStatus?
the status of the order
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig