OrderFailureUpdate class

Inheritance

Constructors

OrderFailureUpdate({String? account, String? orderHash, String? cid, int? errorCode})
const
OrderFailureUpdate.deserialize(List<int> bytes)
factory
OrderFailureUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

account String?
the account address
final
cid String?
the client order ID
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
errorCode int?
the error code
final
hashCode int
The hash code for this object.
no setterinherited
orderHash String?
the order hash
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig