Position class

Inheritance

Constructors

Position({String? marketId, String? subaccountId, bool? isLong, String? quantity, String? entryPrice, String? margin, String? cumulativeFundingEntry})
const
Position.deserialize(List<int> bytes)
factory
Position.fromJson(Map<String, dynamic> json)
factory

Properties

cumulativeFundingEntry String?
the cumulative funding entry of the position (in human readable format)
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
entryPrice String?
the entry price of the position (in human readable format)
final
hashCode int
The hash code for this object.
no setterinherited
isLong bool?
whether the position is long or short
final
margin String?
the margin of the position (in human readable format)
final
marketId String?
the market ID
final
protoValues List<Object?>
no setteroverride
quantity String?
the quantity of the position (in human readable format)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subaccountId String?
the subaccount ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig