MsgUpdateOracleConfig class

MsgUpdateOracleFlag is a message to change oracle config

Inheritance
Mixed-in types

Constructors

MsgUpdateOracleConfig({String? authority, BigInt? bridgeId, bool? oracleEnabled})
const
MsgUpdateOracleConfig.deserialize(List<int> bytes)
factory
MsgUpdateOracleConfig.fromJson(Map<String, dynamic> json)
factory

Properties

authority String?
authority is the address that controls the module (defaults to x/gov unless overwritten) or the current proposer address.
final
bridgeId BigInt?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
oracleEnabled bool?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgUpdateOracleConfigResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgUpdateOracleConfigResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig