duration property

Duration? duration
final

Duration is used to query locks with longer duration than the specified duration. Duration field must not be nil when the lock query type is ByLockDuration.

Implementation

final google_protobuf_duration.Duration? duration;