timestamp property
Timestamp is used by locks started before the specified duration.
Timestamp field must not be nil when the lock query type is ByLockTime.
Querying locks with timestamp is currently not implemented.
Implementation
final google_protobuf_timestamp.Timestamp? timestamp;