maxPoolPointsPerBlock property
max_pool_points_per_block is the maximum number of pool points that can be consumed per block
Implementation
final BigInt? maxPoolPointsPerBlock;
max_pool_points_per_block is the maximum number of pool points that can be consumed per block
final BigInt? maxPoolPointsPerBlock;