QueryGetProtoRevPoolRequest class

QueryGetProtoRevPoolRequest is request type for the Query/GetProtoRevPool RPC method.

Inheritance
Mixed-in types

Constructors

QueryGetProtoRevPoolRequest({String? baseDenom, String? otherDenom})
const
QueryGetProtoRevPoolRequest.deserialize(List<int> bytes)
factory
QueryGetProtoRevPoolRequest.fromJson(Map<String, dynamic> json)
factory

Properties

baseDenom String?
base_denom is the base denom set in protorev for the denom pair to pool mapping
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
otherDenom String?
other_denom is the other denom for the denom pair to pool mapping
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryGetProtoRevPoolResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryGetProtoRevPoolResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig