MsgStoreCode class

Inheritance
Mixed-in types

Constructors

MsgStoreCode({List<int>? sender, List<int>? wasmByteCode, String? source, String? builder})
const
MsgStoreCode.deserialize(List<int> bytes)
factory
MsgStoreCode.fromJson(Map<String, dynamic> json)
factory

Properties

builder String?
Builder is a valid docker image name with tag, optional
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender List<int>?
sender is the canonical address of the sender
final
source String?
Source is a valid absolute HTTPS URI to the contract's source code, optional
final
wasmByteCode List<int>?
WASMByteCode can be raw or gzip compressed
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgStoreCodeResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgStoreCodeResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig