MsgUpdateAdmin class

MsgUpdateAdmin sets a new admin for a smart contract

Inheritance
Mixed-in types

Constructors

MsgUpdateAdmin({String? sender, String? newAdmin, String? contract, List<int>? callbackSig})
const
MsgUpdateAdmin.deserialize(List<int> bytes)
factory
MsgUpdateAdmin.fromJson(Map<String, dynamic> json)
factory

Properties

callbackSig List<int>?
used internally for encryption, should always be empty in a signed transaction
final
contract String?
Contract is the address of the smart contract
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
newAdmin String?
NewAdmin address to be set
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String?
Sender is the that actor that signed the messages
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgUpdateAdminResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgUpdateAdminResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig