CreateResultData class

CreateResultData stores the outcome of a single MsgStoreCode execution

Inheritance

Constructors

CreateResultData({List<int>? wasmHash, List<int>? codeHash, bool? hasError, String? errorMsg})
const
CreateResultData.deserialize(List<int> bytes)
factory
CreateResultData.fromJson(Map<String, dynamic> json)
factory

Properties

codeHash List<int>?
Code hash computed by the enclave (empty on error)
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
errorMsg String?
Error message (if has_error is true)
final
hasError bool?
Whether the enclave rejected the code
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wasmHash List<int>?
SHA256 of the original WASM bytecode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig