CrossModuleOp class

CrossModuleOp represents a storage operation on a different module's store

Inheritance

Constructors

CrossModuleOp({String? storeKey, List<int>? key, List<int>? value, bool? isDelete})
const
CrossModuleOp.deserialize(List<int> bytes)
factory
CrossModuleOp.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isDelete bool?
True if this is a delete operation, false for set
final
key List<int>?
Storage key within the module's store
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeKey String?
The store key identifying the module (e.g., "bank", "staking")
final
value List<int>?
Storage value (empty for delete operations)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig