QueryByContractAddressRequest class

Inheritance
Mixed-in types

Constructors

QueryByContractAddressRequest({String? contractAddress})
const
QueryByContractAddressRequest.deserialize(List<int> bytes)
factory
QueryByContractAddressRequest.fromJson(Map<String, dynamic> json)
factory

Properties

contractAddress String?
address is the bech32 human readable address of the contract
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryContractInfoResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryContractInfoResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig