QueryEncryptedSeedRequest class

QueryEncryptedSeedRequest is the request type for the Query/EncryptedSeed RPC method

Inheritance
Mixed-in types

Constructors

QueryEncryptedSeedRequest({String? certHash, BigInt? height})
const
QueryEncryptedSeedRequest.deserialize(List<int> bytes)
factory
QueryEncryptedSeedRequest.fromJson(Map<String, dynamic> json)
factory

Properties

certHash String?
Certificate hash (hex encoded sha256 of certificate)
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
height BigInt?
Block height at which the seed was recorded (required for per-height keying)
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryEncryptedSeedResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryEncryptedSeedResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig