toJson method
Dont change order of toJson the key index must be equal to protoConfig fields.
Implementation
@override
Map<String, dynamic> toJson() {
return {'hex_address': hexAddress, 'bech32_address': bech32Address};
}
Dont change order of toJson the key index must be equal to protoConfig fields.
@override
Map<String, dynamic> toJson() {
return {'hex_address': hexAddress, 'bech32_address': bech32Address};
}