QueryTraceBlockRequest class

QueryTraceBlockRequest defines TraceTx request

Inheritance
Mixed-in types

Constructors

QueryTraceBlockRequest({List<MsgEthereumTx> txs = const [], TraceConfig? traceConfig, BigInt? blockNumber, String? blockHash, Timestamp? blockTime})
const
QueryTraceBlockRequest.deserialize(List<int> bytes)
factory
QueryTraceBlockRequest.fromJson(Map<String, dynamic> json)
factory

Properties

blockHash String?
block hex hash
final
blockNumber BigInt?
block number
final
blockTime Timestamp?
block time
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
traceConfig TraceConfig?
TraceConfig holds extra parameters to trace functions.
final
txs List<MsgEthereumTx>
txs messages in the block
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQueryResponse(List<int> bytes) QueryTraceBlockResponse
override
onQueryResponseJson(Map<String, dynamic> json) QueryTraceBlockResponse
override
protoConfig() → ProtoMessageConfig
override
requestSpec() → HttpRequestSpec
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig