Metrics class

Inheritance

Constructors

Metrics({String? totalSupply, String? totalMiningSupply, String? totalMinedTokens, String? totalResourceNodesDeposit, String? totalBondedDelegation, String? totalUnbondedDelegation, String? totalUnbondingDelegation, String? circulationSupply, String? totalMiningReward, String? chainMiningReward, String? resourceMiningReward, String? metaMiningReward, String? resourceNodeDeposit, String? metaNodeDeposit, String? unissuedPrepay})
const
Metrics.deserialize(List<int> bytes)
factory
Metrics.fromJson(Map<String, dynamic> json)
factory

Properties

chainMiningReward String?
final
circulationSupply String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metaMiningReward String?
final
metaNodeDeposit String?
final
protoValues List<Object?>
no setteroverride
resourceMiningReward String?
final
resourceNodeDeposit String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBondedDelegation String?
final
totalMinedTokens String?
final
totalMiningReward String?
final
totalMiningSupply String?
final
totalResourceNodesDeposit String?
final
totalSupply String?
final
totalUnbondedDelegation String?
final
totalUnbondingDelegation String?
final
unissuedPrepay String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig