MiningRewardParam class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- MiningRewardParam
Constructors
- MiningRewardParam({Coin? totalMinedValveStart, Coin? totalMinedValveEnd, Coin? miningReward, String? blockChainPercentageInBp, String? resourceNodePercentageInBp, String? metaNodePercentageInBp})
-
const
-
MiningRewardParam.deserialize(List<
int> bytes) -
factory
-
MiningRewardParam.fromJson(Map<
String, dynamic> json) -
factory
Properties
- blockChainPercentageInBp → String?
-
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaNodePercentageInBp → String?
-
final
- miningReward → Coin?
-
final
-
protoValues
→ List<
Object?> -
no setteroverride
- resourceNodePercentageInBp → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalMinedValveEnd → Coin?
-
final
- totalMinedValveStart → Coin?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig