Params class

Params defines the PoT module parameters

Inheritance

Constructors

Params({String? bondDenom, String? rewardDenom, BigInt? matureEpoch, List<MiningRewardParam> miningRewardParams = const [], String? communityTax, Coin? initialTotalSupply})
const
Params.deserialize(List<int> bytes)
factory
Params.fromJson(Map<String, dynamic> json)
factory

Properties

bondDenom String?
final
communityTax String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
initialTotalSupply Coin?
final
matureEpoch BigInt?
final
miningRewardParams List<MiningRewardParam>
final
protoValues List<Object?>
no setteroverride
rewardDenom String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig