MsgUpdateParams class

MsgUpdateParams defines a Msg for updating the x/pot module parameters.

Inheritance
Mixed-in types

Constructors

MsgUpdateParams({String? authority, Params? params})
const
MsgUpdateParams.deserialize(List<int> bytes)
factory
MsgUpdateParams.fromJson(Map<String, dynamic> json)
factory

Properties

authority String?
authority is the address of the governance account.
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
params Params?
params defines the x/pot parameters to update. NOTE: All parameters must be supplied.
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgUpdateParamsResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgUpdateParamsResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig