MsgVolumeReport class

MsgVolumeReport encapsulates an VolumeReport transaction as an SDK message.

Inheritance
Mixed-in types

Constructors

MsgVolumeReport({List<SingleWalletVolume> walletVolumes = const [], String? reporter, String? epoch, String? reportReference, String? reporterOwner, BLSSignatureInfo? blsSignature})
const
MsgVolumeReport.deserialize(List<int> bytes)
factory
MsgVolumeReport.fromJson(Map<String, dynamic> json)
factory

Properties

blsSignature BLSSignatureInfo?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
epoch String?
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
reporter String?
final
reporterOwner String?
final
reportReference String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walletVolumes List<SingleWalletVolume>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgVolumeReportResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgVolumeReportResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig