MsgCreateResourceNode class

MsgCreateResourceNode encapsulates an MsgCreateResourceNodeTx transaction as an SDK message.

Inheritance
Mixed-in types

Constructors

MsgCreateResourceNode({String? networkAddress, Any? pubkey, Coin? value, String? ownerAddress, String? beneficiaryAddress, Description? description, int? nodeType})
const
MsgCreateResourceNode.deserialize(List<int> bytes)
factory
MsgCreateResourceNode.fromJson(Map<String, dynamic> json)
factory

Properties

beneficiaryAddress String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
description Description?
final
hashCode int
The hash code for this object.
no setterinherited
networkAddress String?
final
nodeType int?
final
ownerAddress String?
final
protoValues List<Object?>
no setteroverride
pubkey Any?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Coin?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateResourceNodeResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateResourceNodeResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig