UserAllocation class

UserAllocation tracks the status of an allocation for a user on a specific airdrop

Inheritance

Constructors

UserAllocation({String? airdropId, String? address, String? claimed, String? forfeited, List<String> allocations = const []})
const
UserAllocation.deserialize(List<int> bytes)
factory
UserAllocation.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
Address of the account that is receiving the airdrop allocation The address does not have to be a stride address - but non-stride addresses must be linked and merged into a stride address before claiming
final
airdropId String?
ID of the airdrop
final
allocations List<String>
The current state of allocations for this airdrop
final
claimed String?
The total amount of tokens that have already been claimed
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
forfeited String?
The total amount of tokens that have been forfeited by the user for claiming early
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig