QueryAirdropResponse class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryAirdropResponse
Constructors
- QueryAirdropResponse({String? id, String? rewardDenom, Timestamp? distributionStartDate, Timestamp? distributionEndDate, Timestamp? clawbackDate, Timestamp? claimTypeDeadlineDate, String? earlyClaimPenalty, String? distributorAddress, String? allocatorAddress, String? linkerAddress, BigInt? currentDateIndex, BigInt? airdropLength})
-
const
-
QueryAirdropResponse.deserialize(List<
int> bytes) -
factory
-
QueryAirdropResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- airdropLength → BigInt?
-
The length of the airdrop (i.e. number of periods in the airdrop array)
final
- allocatorAddress → String?
-
Admin account with permissions to add or update allocations
final
- claimTypeDeadlineDate → Timestamp?
-
Deadline for the user to make a decision on their claim type
final
- clawbackDate → Timestamp?
-
Date with which the rewards are clawed back (occurs after the distribution
end date)
final
- currentDateIndex → BigInt?
-
The current date index into the airdrop array
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- distributionEndDate → Timestamp?
-
The last date for rewards to be distributed. Immediately after this date
the rewards can no longer be claimed, but rewards have not been clawed back
yet
final
- distributionStartDate → Timestamp?
-
The first date that claiming begins and rewards are distributed
final
- distributorAddress → String?
-
Account that holds the total reward balance and distributes to users
final
- earlyClaimPenalty → String?
-
Penalty for claiming rewards early - e.g. 0.5 means claiming early will
result in losing 50% of rewards
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Airdrop ID
final
- linkerAddress → String?
-
Admin account with permissions to link addresseses
final
-
protoValues
→ List<
Object?> -
no setteroverride
- rewardDenom → String?
-
Denom used when distributing rewards
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig