clawbackDate property
Date with which the rewards are clawed back (occurs after the distribution end date)
Implementation
final google_protobuf_timestamp.Timestamp? clawbackDate;
Date with which the rewards are clawed back (occurs after the distribution end date)
final google_protobuf_timestamp.Timestamp? clawbackDate;