distributorAddress property
Account that holds the total reward balance and distributes to users
Implementation
final String? distributorAddress;
Account that holds the total reward balance and distributes to users
final String? distributorAddress;