MsgCreateAirdrop class

CreateAirdrop

Inheritance
Mixed-in types

Constructors

MsgCreateAirdrop({String? admin, String? airdropId, String? rewardDenom, Timestamp? distributionStartDate, Timestamp? distributionEndDate, Timestamp? clawbackDate, Timestamp? claimTypeDeadlineDate, String? earlyClaimPenalty, String? distributorAddress, String? allocatorAddress, String? linkerAddress})
const
MsgCreateAirdrop.deserialize(List<int> bytes)
factory
MsgCreateAirdrop.fromJson(Map<String, dynamic> json)
factory

Properties

admin String?
Airdrop admin address
final
airdropId String?
Airdrop ID
final
allocatorAddress String?
Admin account with permissions to add or update allocations
final
claimTypeDeadlineDate Timestamp?
Deadline for the user to make a decision on their claim type
final
clawbackDate Timestamp?
Date with which the rewards are clawed back (occurs after the distribution end date)
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
distributionEndDate Timestamp?
The last date for rewards to be distributed. Immediately after this date the rewards can no longer be claimed, but rewards have not been clawed back yet
final
distributionStartDate Timestamp?
The first date that claiming begins and rewards are distributed
final
distributorAddress String?
Account that holds the total reward balance and distributes to users
final
earlyClaimPenalty String?
Penalty for claiming rewards early - e.g. 0.5 means claiming early will result in losing 50% of rewards
final
hashCode int
The hash code for this object.
no setterinherited
linkerAddress String?
Admin account with permissions to link addresseses
final
protoValues List<Object?>
no setteroverride
rewardDenom String?
Denom used when distributing rewards
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateAirdropResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateAirdropResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig