MsgLinkAddresses class

LinkAddresses

Inheritance
Mixed-in types

Constructors

MsgLinkAddresses({String? admin, String? airdropId, String? strideAddress, String? hostAddress})
const
MsgLinkAddresses.deserialize(List<int> bytes)
factory
MsgLinkAddresses.fromJson(Map<String, dynamic> json)
factory

Properties

admin String?
Airdrop admin address
final
airdropId String?
Airdrop ID
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hostAddress String?
Host address - this address must exist
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strideAddress String?
Stride address - this address may or may not exist in allocations yet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgLinkAddressesResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgLinkAddressesResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig