proto_messages/stride/auction/models library

Classes

Auction
MsgCreateAuction
MsgCreateAuction defines the message for adding a token auction
MsgCreateAuctionResponse
MsgPlaceBid
MsgPlaceBid defines the message for bidding in a token auction
MsgPlaceBidResponse
MsgUpdateAuction
MsgUpdateAuction defines the message for adding a token auction
MsgUpdateAuctionResponse
QueryAuctionRequest
QueryAuctionRequest is the request type for the Query/Auction RPC method
QueryAuctionResponse
QueryAuctionResponse is the response type for the Query/Auction RPC method
QueryAuctionsRequest
QueryAuctionsRequest is the request type for the Query/Auctions RPC method
QueryAuctionsResponse
QueryAuctionsResponse is the response type for the Query/Auctions RPC method

Enums

AuctionType