Airdrop class

Inheritance

Constructors

Airdrop({String? airdropIdentifier, String? chainId, Timestamp? airdropStartTime, Duration? airdropDuration, String? claimDenom, String? distributorAddress, String? claimedSoFar, bool? autopilotEnabled})
const
Airdrop.deserialize(List<int> bytes)
factory
Airdrop.fromJson(Map<String, dynamic> json)
factory

Properties

airdropDuration Duration?
seconds
final
airdropIdentifier String?
final
airdropStartTime Timestamp?
seconds
final
autopilotEnabled bool?
indicates the airdrop should be claimed via autopilot
final
chainId String?
final
claimDenom String?
denom of claimable asset
final
claimedSoFar String?
ustrd tokens claimed so far in the current period
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
distributorAddress String?
airdrop distribution account
final
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig