MsgCreateAirdrop class

Inheritance
Mixed-in types

Constructors

MsgCreateAirdrop({String? distributor, String? identifier, String? chainId, String? denom, BigInt? startTime, BigInt? duration, bool? autopilotEnabled})
const
MsgCreateAirdrop.deserialize(List<int> bytes)
factory
MsgCreateAirdrop.fromJson(Map<String, dynamic> json)
factory

Properties

autopilotEnabled bool?
final
chainId String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
denom String?
final
distributor String?
final
duration BigInt?
final
hashCode int
The hash code for this object.
no setterinherited
identifier String?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime BigInt?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateAirdropResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateAirdropResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig