CallbackData class

Inheritance

Constructors

CallbackData({String? callbackKey, String? portId, String? channelId, BigInt? sequence, String? callbackId, List<int>? callbackArgs})
const
CallbackData.deserialize(List<int> bytes)
factory
CallbackData.fromJson(Map<String, dynamic> json)
factory

Properties

callbackArgs List<int>?
final
callbackId String?
final
callbackKey String?
final
channelId String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
portId String?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence BigInt?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig