MsgRegisterTokenPriceQuery class

MsgRegisterTokenPriceQuery defines the message for adding a new token to track prices

Inheritance
Mixed-in types

Constructors

MsgRegisterTokenPriceQuery({String? admin, String? baseDenom, String? quoteDenom, String? osmosisBaseDenom, String? osmosisQuoteDenom, BigInt? osmosisPoolId})
const
MsgRegisterTokenPriceQuery.deserialize(List<int> bytes)
factory
MsgRegisterTokenPriceQuery.fromJson(Map<String, dynamic> json)
factory

Properties

admin String?
final
baseDenom String?
Token denom on Stride
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
osmosisBaseDenom String?
Token denom on Osmosis
final
osmosisPoolId BigInt?
Pool ID on Osmosis
final
osmosisQuoteDenom String?
Quote denom on Osmosis
final
protoValues List<Object?>
no setteroverride
quoteDenom String?
Quote denom on Stride
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgRegisterTokenPriceQueryResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgRegisterTokenPriceQueryResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig