MsgRemoveTokenPriceQuery class
MsgRemoveTokenPriceQuery defines the message for removing a token from price tracking
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- MsgRemoveTokenPriceQuery
- Mixed-in types
Constructors
- MsgRemoveTokenPriceQuery({String? admin, String? baseDenom, String? quoteDenom, BigInt? osmosisPoolId})
-
const
-
MsgRemoveTokenPriceQuery.deserialize(List<
int> bytes) -
factory
-
MsgRemoveTokenPriceQuery.fromJson(Map<
String, dynamic> json) -
factory
Properties
- admin → String?
-
final
- baseDenom → String?
-
Token denom on Stride
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- osmosisPoolId → BigInt?
-
Pool ID on Osmosis
final
-
protoValues
→ List<
Object?> -
no setteroverride
- quoteDenom → String?
-
Quote denom on Stride
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onServiceResponse(
List< int> bytes) → MsgRemoveTokenPriceQueryResponse -
override
-
onServiceResponseJson(
Map< String, dynamic> json) → MsgRemoveTokenPriceQueryResponse -
override
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAminoJson(
{CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig