MsgSubmitQueryResponse class

MsgSubmitQueryResponse represents a message type to fulfil a query request.

Inheritance
Mixed-in types

Constructors

MsgSubmitQueryResponse({String? chainId, String? queryId, List<int>? result, ProofOps? proofOps, BigInt? height, String? fromAddress})
const
MsgSubmitQueryResponse.deserialize(List<int> bytes)
factory
MsgSubmitQueryResponse.fromJson(Map<String, dynamic> json)
factory

Properties

chainId String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
fromAddress String?
final
hashCode int
The hash code for this object.
no setterinherited
height BigInt?
final
proofOps ProofOps?
final
protoValues List<Object?>
no setteroverride
queryId String?
final
result List<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgSubmitQueryResponseResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgSubmitQueryResponseResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig