RedemptionRecordResponse class

Data structure for frontend to consume

Inheritance

Constructors

RedemptionRecordResponse({RedemptionRecord? redemptionRecord, BigInt? unbondingCompletionTimeSeconds})
const
RedemptionRecordResponse.deserialize(List<int> bytes)
factory
RedemptionRecordResponse.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setteroverride
redemptionRecord RedemptionRecord?
Redemption record
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unbondingCompletionTimeSeconds BigInt?
The Unix timestamp (in seconds) at which the unbonding for the UR associated with this RR completes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig