MsgSetOperatorAddress class

SetOperatorAddress

Inheritance
Mixed-in types

Constructors

MsgSetOperatorAddress({String? signer, String? operator_})
const
MsgSetOperatorAddress.deserialize(List<int> bytes)
factory
MsgSetOperatorAddress.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
operator_ String?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signer String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgSetOperatorAddressResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgSetOperatorAddressResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig