CommunityPoolRebate class

CommunityPoolRebate stores the size of the community pool liquid stake (denominated in stTokens) and the rebate rate as a decimal

Inheritance

Constructors

CommunityPoolRebate({String? rebateRate, String? liquidStakedStTokenAmount})
const
CommunityPoolRebate.deserialize(List<int> bytes)
factory
CommunityPoolRebate.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
liquidStakedStTokenAmount String?
Number of stTokens received from the community pool liquid stake
final
protoValues List<Object?>
no setteroverride
rebateRate String?
Rebate percentage as a decimal (e.g. 0.2 for 20%)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig