toJson method
Dont change order of toJson the key index must be equal to protoConfig fields.
Implementation
@override
Map<String, dynamic> toJson() {
return {'channel_id': channelId, 'port_id': portId};
}
Dont change order of toJson the key index must be equal to protoConfig fields.
@override
Map<String, dynamic> toJson() {
return {'channel_id': channelId, 'port_id': portId};
}