MsgCreateTradeRoute class

Creates a new trade route

Inheritance
Mixed-in types

Constructors

MsgCreateTradeRoute({String? authority, String? hostChainId, String? strideToRewardConnectionId, String? strideToTradeConnectionId, String? hostToRewardTransferChannelId, String? rewardToTradeTransferChannelId, String? tradeToHostTransferChannelId, String? rewardDenomOnHost, String? rewardDenomOnReward, String? rewardDenomOnTrade, String? hostDenomOnTrade, String? hostDenomOnHost, BigInt? poolId, String? maxAllowedSwapLossRate, String? minSwapAmount, String? maxSwapAmount, String? minTransferAmount})
const
MsgCreateTradeRoute.deserialize(List<int> bytes)
factory
MsgCreateTradeRoute.fromJson(Map<String, dynamic> json)
factory

Properties

authority String?
authority is the address that controls the module (defaults to x/gov unless overwritten).
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hostChainId String?
The chain ID of the host zone
final
hostDenomOnHost String?
the host zone's native denom (e.g. dydx on dYdX)
final
hostDenomOnTrade String?
ibc denom of the host's token on the trade zone (e.g. ibc/dydx on Osmosis)
final
hostToRewardTransferChannelId String?
Transfer channels between the host, reward, and trade zones
final
maxAllowedSwapLossRate String?
Deprecated, the trades are now executed off-chain via authz
final
maxSwapAmount String?
Deprecated, the trades are now executed off-chain via authz
final
minSwapAmount String?
Deprecated, the trades are now executed off-chain via authz
final
minTransferAmount String?
Minimum amount of reward token that must be accumulated before the tokens are transferred to the trade ICA
final
poolId BigInt?
Deprecated, the trades are now executed off-chain via authz
final
protoValues List<Object?>
no setteroverride
rewardDenomOnHost String?
ibc denom for the reward token on the host zone (e.g. ibc/usdc on dYdX)
final
rewardDenomOnReward String?
native denom of reward token on the reward zone (e.g. usdc on Noble)
final
rewardDenomOnTrade String?
ibc denom of the reward token on the trade zone (e.g. ibc/usdc on Osmosis)
final
rewardToTradeTransferChannelId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strideToRewardConnectionId String?
Connection IDs between stride and the other zones
final
strideToTradeConnectionId String?
final
tradeToHostTransferChannelId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgCreateTradeRouteResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgCreateTradeRouteResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig