MsgSetCommunityPoolRebate class

Registers or updates a community pool rebate by specifying the amount liquid staked

Inheritance
Mixed-in types

Constructors

MsgSetCommunityPoolRebate({String? creator, String? chainId, String? rebateRate, String? liquidStakedStTokenAmount})
const
MsgSetCommunityPoolRebate.deserialize(List<int> bytes)
factory
MsgSetCommunityPoolRebate.fromJson(Map<String, dynamic> json)
factory

Properties

chainId String?
Chain id of the chain whose community pool has a liquid staking rebate arrangement with stride
final
creator String?
Message signer (admin only)
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
liquidStakedStTokenAmount String?
Number of stTokens recieved by the community pool after liquid staking
final
protoValues List<Object?>
no setteroverride
rebateRate String?
Rebate percentage represented as a decimal (e.g. 0.2 for 20%)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgSetCommunityPoolRebateResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgSetCommunityPoolRebateResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig