MsgToggleTradeController class

Grants or revokes trade permissions to a given address via authz

Inheritance
Mixed-in types

Constructors

MsgToggleTradeController({String? creator, String? chainId, AuthzPermissionChange? permissionChange, String? address, bool? legacy})
const
MsgToggleTradeController.deserialize(List<int> bytes)
factory
MsgToggleTradeController.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
Address of trade operator
final
chainId String?
Chain ID of the trade account
final
creator String?
Message signer (admin only)
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
legacy bool?
Option to grant/revoke the legacy osmosis swap message
final
permissionChange AuthzPermissionChange?
Permission change (either grant or revoke)
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgToggleTradeControllerResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgToggleTradeControllerResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig