MsgUpdateTradeRoute class

Updates the config of a trade route

Inheritance
Mixed-in types

Constructors

MsgUpdateTradeRoute({String? authority, String? rewardDenom, String? hostDenom, BigInt? poolId, String? maxAllowedSwapLossRate, String? minSwapAmount, String? maxSwapAmount, String? minTransferAmount})
const
MsgUpdateTradeRoute.deserialize(List<int> bytes)
factory
MsgUpdateTradeRoute.fromJson(Map<String, dynamic> json)
factory

Properties

authority String?
authority is the address that controls the module (defaults to x/gov unless overwritten).
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hostDenom String?
The host zone's denom in it's native form (e.g. dydx)
final
maxAllowedSwapLossRate String?
Deprecated, the trades are now executed off-chain via authz
final
maxSwapAmount String?
Deprecated, the trades are now executed off-chain via authz
final
minSwapAmount String?
Deprecated, the trades are now executed off-chain via authz
final
minTransferAmount String?
Minimum amount of reward token that must be accumulated before the tokens are transferred to the trade ICA
final
poolId BigInt?
Deprecated, the trades are now executed off-chain via authz
final
protoValues List<Object?>
no setteroverride
rewardDenom String?
The reward denom of the route in it's native form (e.g. usdc)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onServiceResponse(List<int> bytes) MsgUpdateTradeRouteResponse
override
onServiceResponseJson(Map<String, dynamic> json) MsgUpdateTradeRouteResponse
override
protoConfig() → ProtoMessageConfig
override
toAminoJson({CosmosBech32Config? config}) Map<String, dynamic>
inherited
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig