Validator class

Inheritance

Constructors

Validator({String? name, String? address, BigInt? weight, String? delegation, String? slashQueryProgressTracker, String? slashQueryCheckpoint, String? sharesToTokensRate, BigInt? delegationChangesInProgress, bool? slashQueryInProgress})
const
Validator.deserialize(List<int> bytes)
factory
Validator.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
delegation String?
final
delegationChangesInProgress BigInt?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharesToTokensRate String?
final
slashQueryCheckpoint String?
final
slashQueryInProgress bool?
final
slashQueryProgressTracker String?
final
weight BigInt?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig