ProofOp class

ProofOp defines an operation used for calculating Merkle root The data could be arbitrary format, providing necessary data for example neighbouring node hash

Inheritance

Constructors

ProofOp({String? type, List<int>? key, List<int>? data})
const
ProofOp.deserialize(List<int> bytes)
factory
ProofOp.fromJson(Map<String, dynamic> json)
factory

Properties

data List<int>?
final
declarationId DefaultCosmosProtoTypeUrl
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
key List<int>?
final
protoValues List<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig