proto_messages/tendermint/version/models library

Classes

Consensus
Consensus captures the consensus rules for processing a block in the blockchain, including all blockchain data structures and the rules of the application's state transition machine.