proto_messages/thorchain/common/src/common library
Classes
- Asset
- Attestation
- Coin
- ErrataTx
- NetworkFee
- ObservedTx
- OraclePrice
- OutputRef
- PriceFeed
- PubKeySet
- PubKeySet contains two pub keys , secp256k1 and ed25519
- QuorumErrataTx
- QuorumNetworkFee
- QuorumPriceFeed
- QuorumPriceFeedBatch
- QuorumSolvency
- QuorumTx
- allow future observation if this is an instant observation and gas is wrong, requiring future observation to correct
- Solvency
- Tx