CosmosPrivateKey class abstract

Inheritance
Implementers

Constructors

CosmosPrivateKey()
const
CosmosPrivateKey.fromBytes({required List<int> keyBytes, required CosmosKeysAlgs algorithm})
factory

Properties

declarationId CosmosProtoTypeUrl
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
inherited
sign(List<int> digest) List<int>
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toBytes() List<int>
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
inherited
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toPublicKey() CosmosPublicKey
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited