CosmosQuickServiceApi<PROVIDER extends IProvider<IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, IServiceRequestParams>> mixin

Properties

hashCode int
The hash code for this object.
no setterinherited
provider → PROVIDER
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedApis List<CosmosProviderApi>
no setter

Methods

broadcastTransaction(List<int> txRaw, {Duration? timeout}) Future<String>
chainId({Duration? timeout}) Future<String>
foldApi<T extends Object>({required Future<T> onTendermint(IProvider<IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, IServiceRequestParams> provider), required Future<T> onRest(IProvider<IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, IServiceRequestParams> provider), required Future<T> onGrpc(IGrpcProvider<IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, IServiceRequestParams, BaseGRPCServiceRequestParams> provider), CosmosProviderApi? api}) Future<T>
getAccount(CosmosBaseAddress address, {Duration? timeout}) Future<BaseAccount>
getAddressCoins(CosmosBaseAddress address, {Duration? timeout}) Future<List<Coin>>
getBalance(CosmosBaseAddress address, String denom, {Duration? timeout}) Future<BigInt>
getBlockHeight({Duration? timeout}) Future<BigInt?>
getEthereumBaseFee({Duration? timeout}) Future<BigRational?>
getLatestBlock({Duration? timeout}) Future<GetLatestBlockResponse>
getTransaction(String hash, {Duration? timeout}) Future<GetTxResponse>
networkBech32({Duration? timeout}) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query<T extends CosmosProtoMessage>(ICosmosProtoQueryMessage<T> message, {Duration? timeout, CosmosProviderApi? api}) Future<T>
queryDynamic<T extends CosmosProtoMessage>(ICosmosProtoQueryMessage<T> message, {Duration? timeout}) Future
simulateTx(List<int> txBytes, {List<ICosmosProtoServiceMessage<CosmosProtoMessage>> txMessages = const [], Duration? timeout}) Future<SimulateResponse>
toString() String
A string representation of this object.
inherited
totalSupply(String denom, {Duration? timeout}) Future<BigInt>
tryGetAccount(CosmosBaseAddress address, {Duration? timeout}) Future<BaseAccount?>

Operators

operator ==(Object other) bool
The equality operator.
inherited