CosmosRequest<RESULT, RESPONSE, R extends BaseCosmosRequestDetails> class
abstract
- Inheritance
-
- Object
- BaseServiceRequest<
RESULT, RESPONSE, R> - CosmosRequest
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestMethod → RequestMethod
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRequest(
int requestID) → R -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onResonse(
RESPONSE result) → RESULT -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited