CosmosRestRequest<RESULT, RESPONSE> class abstract

An abstract class representing request parameters for tendermint API calls.

Inheritance
Implementers

Constructors

CosmosRestRequest()

Properties

body Map<String, dynamic>?
no setter
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, dynamic>
no setter
path String
method for the request.
final
requestMethod → RequestMethod
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildRequest(int id) CosmosRestRequestDetails
Converts the request parameters to TendermintRequestDetails with a unique identifier.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onResonse(RESPONSE result) → RESULT
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited