CosmosRestRequestDetails class

Inheritance

Constructors

CosmosRestRequestDetails({required int requestID, required String? path, required ServiceReponseEncoding responseEncoding, RequestMethod requestMethod = RequestMethod.get, List<int>? errorStatusCodes = const [500, 404], Map<String, String> headers = const {}, String? bodyString})
const
CosmosRestRequestDetails.deserialize({List<int>? bytes, CborObject<Object?>? obj})
factory

Properties

api CosmosProviderApi
finalinherited
bodyBytes List<int>?
finalinherited
bodyString String?
finalinherited
errorStatusCodes List<int>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
finalinherited
network → BlockchainNetwork?
finalinherited
path String?
finalinherited
requestID int
finalinherited
requestMethod → RequestMethod
finalinherited
responseEncoding → ServiceReponseEncoding
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier → SerializationIdentifier
no setterinherited
serializationItems List<CborObject<Object?>?>
no setterinherited
successStatusCodes List<int>?
finalinherited

Methods

copyWith({int? requestID, String? path, Map<String, String>? headers, ServiceReponseEncoding? responseEncoding, RequestMethod? requestMethod, String? bodyString, List<int>? errorStatusCodes}) CosmosRestRequestDetails
encodeBody({ServiceProtocol protocol = ServiceProtocol.http}) List<int>?
Encodes the request payload into bytes.
inherited
encodeUrl(String uri) Uri
Builds the final request URI.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() → CborTagValue<CborObject<Object?>>
inherited
toEncodingResponse<T>(BaseServiceResponse response, {ServiceReponseEncoding? encoding}) → T
Converts a BaseServiceResponse into the specified encoding type.
inherited
toJson() Map<String, dynamic>
inherited
toResponse(Object? response, {int statusCode = 200}) → BaseServiceResponse
Decodes a raw service response into a BaseServiceResponse.
inherited
toString() String
A string representation of this object.
inherited
tryEncodingResponse<T>(BaseServiceResponse response, {ServiceReponseEncoding? encoding}) → T?
Attempts to convert a successful response to the requested encoding type.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited