TendermintRequestCommit class

Get commit results at a specified height https://docs.tendermint.com/v0.34/rpc/#/Info/commit

Inheritance

Constructors

TendermintRequestCommit({int? height})

Properties

body Map<String, dynamic>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height int?
height to return. If no height is provided, it will fetch information regarding the latest block.
final
method String
Get commit results at a specified height
no setteroverride
parameters Map<String, String?>
no setteroverride
pathParameters List<String>
list of path parameters variable
no setteroverride
requestMethod → RequestMethod
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildRequest(int id) TendermintRequestDetails
Converts the request parameters to TendermintRequestDetails with a unique identifier.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onResonse(Map<String, dynamic> result) TendermintCommitResponseResult
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited