height property
height to return. If no height is provided, it will fetch information regarding the latest block.
Implementation
final int? height;
height to return. If no height is provided, it will fetch information regarding the latest block.
final int? height;