sdk/provider/provider
library
Classes
-
AsgardResponse
-
-
AssetBorrowerPositionResponse
-
-
AssetLiquidityProviderInformationResponse
-
-
AssetPoolInformationResponse
-
-
AssetSaverPositionResponse
-
-
AssetTradeInfoResponse
-
-
BaseCosmosRequestDetails
-
-
BaseCosmosServiceRequestParams
-
-
CCRApi
-
-
CCRApis
-
-
CCRAsset
-
-
CCRAssetChain
-
-
CCRAssetList
-
-
CCRBech32Config
-
-
CCRBinaries
-
-
CCRChain
-
-
CCRChainBridge
-
-
CCRChainCw20
-
-
CCRChainData
-
-
CCRChainInfo
-
-
CCRChainNonIbc
-
-
CCRChainOperatorInfo
-
-
CCRChannelInfo
-
-
CCRCodebase
-
-
CCRConsensus
-
-
CCRConst
-
-
CCRCosmwasm
-
-
CCRCounterparty
-
-
CCRCounterpartyBridge
-
-
CCRCounterpartyCw20
-
-
CCRCounterpartyNonIbc
-
-
CCRDenomUnit
-
-
CCREndpoint
-
-
CCRExplorer
-
-
CCRFees
-
-
CCRFeeToken
-
-
CCRGasCosts
-
-
CCRGenesis
-
-
CCRIbc
-
-
CCRIbcBridgeTransition
-
-
CCRIbcCw20Transition
-
-
CCRIBCData
-
-
CCRIbcData
-
-
CCRIbcTransactionBase
-
-
CCRIbcTransition
-
-
CCRImageData
-
-
CCRImageResource
-
-
CCRLanguage
-
-
CCRLockDuration
-
-
CCRLogoURIs
-
-
CCRLogoUris
-
-
CCRNonIbcTransition
-
-
CCRPeer
-
-
CCRPeers
-
-
CCRPointer
-
-
CCRSdk
-
-
CCRSocials
-
-
CCRStaking
-
-
CCRStakingToken
-
-
CCRTheme
-
-
CCRUtilities
-
-
CCRVersionInfo
-
-
ChainRegistryProvider<SERVICE extends IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>>
-
-
ChainRegistryRequest<RESULT, RESPONSE>
-
-
ChainRegistryRequestCosmosDirectoryChain
-
-
ChainRegistryRequestCosmosDirectoryChains
-
-
ChainRegistryRequestPingPubAssets
-
-
ChainRegistryRequestPingPubChain
-
-
ChainRegistryRequestPingPubChains
-
-
ChainRegistryRequestRequestDetails
-
-
CloutScoreResponse
-
-
CosmosChannelInfo
-
-
CosmosDirectoryAsset
-
-
CosmosDirectoryChain
-
-
CosmosGrpcRequest<RESULT>
-
-
CosmosGrpcRequestDetails
-
-
CosmosGrpcRequestMessage<Response extends CosmosProtoMessage>
-
-
CosmosProvider<SERVICE extends IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>>
-
Facilitates communication with the tendermint by making requests using a provided CosmosProvider.
-
CosmosProviderUtils
-
-
CosmosRequest<RESULT, RESPONSE, R extends BaseCosmosRequestDetails>
-
-
CosmosRestRequest<RESULT, RESPONSE>
-
An abstract class representing request parameters for tendermint API calls.
-
CosmosRestRequestDetails
-
-
CosmosRestRequestMessage<Response extends CosmosProtoMessage>
-
-
CosmosSdkAsset
-
-
CosmosSdkChain
-
-
CosmosSdkChainChains
-
-
CosmosServiceRequestParams
-
-
CosmosSkdExplorer
-
-
DerivedAssetPoolInformationResponse
-
-
PingPubChain
-
https://registry.ping.pub/
-
PolStaticsResponse
-
-
StreamingSwapStateResponse
-
-
TendermintABCIInfoResponseResult
-
-
TendermintABCIInfoResponseResultResponse
-
-
TendermintABCIQueryResponseResult
-
-
TendermintABCIQueryResponseResultResponse
-
-
TendermintBlock
-
-
TendermintBlockchain
-
-
TendermintBlockComplete
-
-
-
-
TendermintBlockID
-
-
TendermintBlockIDParts
-
-
TendermintBlockMeta
-
-
TendermintBlockResultsResponseResult
-
-
TendermintBlockResultsResponseResultFinalizeBlockEvents
-
-
TendermintBlockResultsResponseResultTxsResults
-
-
TendermintBlockResultsResponseResultTxsResultsEvents
-
-
TendermintBlockResultsResponseResultValidatorUpdates
-
-
TendermintBlockResultsResponseResultValidatorUpdatesPubKey
-
-
TendermintBlockSearchResponseResult
-
-
TendermintBroadcastTxCommitResponseResult
-
-
TendermintBroadcastTxCommitResponseResultCheckTx
-
-
TendermintBroadcastTxCommitResponseResultDeliverTx
-
-
TendermintBroadcastTxResponseResult
-
-
TendermintChannel
-
-
TendermintCheckTxResponseResult
-
-
TendermintCheckTxResponseResultEvents
-
-
TendermintCommit
-
-
TendermintCommitResponseResult
-
-
-
-
-
TendermintConnectionStatus
-
-
TendermintConsensusParams
-
-
TendermintConsensusParamsBlock
-
-
TendermintConsensusParamsEvidence
-
-
TendermintConsensusParamsResponseResult
-
-
TendermintConsensusParamsValidator
-
-
TendermintConsensusStateResponseResult
-
-
TendermintConsensusStateResponseResultRoundState
-
-
TendermintConsensusStateResponseResultRoundStateHeightVoteSet
-
-
TendermintConsensusStateResponseResultRoundStateProposer
-
-
TendermintdialResp
-
-
TendermintDumpConsensusResponseResult
-
-
TendermintDumpConsensusResponseResultPeers
-
-
TendermintDumpConsensusResponseResultPeersPeerStateRoundState
-
-
-
TendermintDumpConsensusResponseResultPeersPeerStateStats
-
-
TendermintEvent
-
-
TendermintEvidence
-
-
TendermintGenesisChunkedResponseResult
-
-
TendermintGenesisResponseResult
-
-
TendermintGenesisResponseResultGenesis
-
-
TendermintGenesisResponseResultGenesisValidators
-
-
TendermintGenesisResponseResultGenesisValidatorsPubKey
-
-
TendermintMethods
-
-
TendermintMonitor
-
-
TendermintNetInfo
-
-
TendermintNodeInfo
-
-
-
TendermintNumUnconfirmedTransactionsResponseResult
-
-
TendermintPeer
-
-
TendermintProtocolVersion
-
-
TendermintPubKey
-
-
TendermintRequest<RESULT, RESPONSE>
-
An abstract class representing request parameters for tendermint API calls.
-
TendermintRequestAbciQuery<Response extends CosmosProtoMessage>
-
Query the application for some information.
https://docs.tendermint.com/v0.34/rpc/#/ABCI/abci_query
-
TendermintRequestBlock
-
Get Block.
https://docs.tendermint.com/v0.34/rpc/#/Info/block
-
TendermintRequestBlockByHash
-
Get block by hash.
https://docs.tendermint.com/v0.34/rpc/#/Info/block_by_hash
-
TendermintRequestBlockchain
-
Get block headers (max: 20) for minHeight <= height <= maxHeight.
https://docs.tendermint.com/v0.34/rpc/#/Info/blockchain
-
TendermintRequestBlockResults
-
Block results.
https://docs.tendermint.com/v0.34/rpc/#/Info/block_results
-
TendermintRequestBlockSearch
-
Search for blocks by BeginBlock and EndBlock events.
See /subscribe for the query syntax.
https://docs.tendermint.com/v0.34/rpc/#/Info/block_search
-
TendermintRequestBroadcastAbciInfo
-
Get info about the application.
https://docs.tendermint.com/v0.34/rpc/#/ABCI/abci_info
-
TendermintRequestBroadcastAbciQuery
-
Query the application for some information.
https://docs.tendermint.com/v0.34/rpc/#/ABCI/abci_query
-
TendermintRequestBroadcastCheckTx
-
Checks the transaction without executing it.
https://docs.tendermint.com/v0.34/rpc/#/Tx/check_tx
-
TendermintRequestBroadcastDialPeers
-
Add Peers/Persistent Peers
https://docs.tendermint.com/v0.34/rpc/#/Unsafe/dial_peers
-
TendermintRequestBroadcastDialSeeds
-
Dial a peer, this route in under unsafe, and has to manually enabled to use
https://docs.tendermint.com/v0.34/rpc/#/Unsafe/dial_seeds
-
TendermintRequestBroadcastEvidence
-
Broadcast evidence of the misbehavior.
https://docs.tendermint.com/v0.34/rpc/#/Info/broadcast_evidence
-
TendermintRequestBroadcastTxAsync
-
Returns right away, with no response. Does not wait for CheckTx nor DeliverTx results.
https://docs.tendermint.com/v0.34/rpc/#/Tx/broadcast_tx_async
-
TendermintRequestBroadcastTxCommit
-
Returns with the responses from CheckTx and DeliverTx.
https://docs.tendermint.com/v0.34/rpc/#/Tx/broadcast_tx_commit
-
TendermintRequestBroadcastTxSync
-
Returns with the response from CheckTx. Does not wait for DeliverTx result.
https://docs.tendermint.com/v0.34/rpc/#/Tx/broadcast_tx_sync
-
TendermintRequestCommit
-
Get commit results at a specified height
https://docs.tendermint.com/v0.34/rpc/#/Info/commit
-
TendermintRequestConsensusParams
-
Get consensus parameters
https://docs.tendermint.com/v0.34/rpc/#/Info/consensus_params
-
TendermintRequestConsensusState
-
Get consensus state
https://docs.tendermint.com/v0.34/rpc/#/Info/consensus_state
-
TendermintRequestDetails
-
-
TendermintRequestDumpConsensusState
-
Get consensus state
https://docs.tendermint.com/v0.34/rpc/#/Info/dump_consensus_state
-
TendermintRequestGenesis
-
Get Genesis
https://docs.tendermint.com/v0.34/rpc/#/Info/genesis
-
TendermintRequestGenesisChunked
-
Get Genesis in multiple chunks
https://docs.tendermint.com/v0.34/rpc/#/Info/genesis_chunked
-
TendermintRequestHealth
-
Gets Node Health
https://docs.tendermint.com/v0.34/rpc/#/Info/health
-
TendermintRequestNetInfo
-
Network informations
https://docs.tendermint.com/v0.34/rpc/#/Info/net_info
-
TendermintRequestNumUnconfirmedTxs
-
Get data about unconfirmed transactions
https://docs.tendermint.com/v0.34/rpc/#/Info/num_unconfirmed_txs
-
TendermintRequestOrderingResponse
-
-
TendermintRequestRemoveTx
-
-
TendermintRequestStatus
-
Node Status
https://docs.tendermint.com/v0.34/rpc/#/Info/status
-
TendermintRequestSubscribe
-
Subscribe for events via WebSocket.
https://docs.tendermint.com/v0.34/rpc/#/Websocket/subscribe
-
TendermintRequestTx
-
Get transactions by hash
https://docs.tendermint.com/v0.34/rpc/#/Info/tx
-
TendermintRequestTxSearch
-
Search for transactions
https://docs.tendermint.com/v0.34/rpc/#/Info/tx_search
-
TendermintRequestUnconfirmedTxs
-
Get the list of unconfirmed transactions
https://docs.tendermint.com/v0.34/rpc/#/Info/unconfirmed_txs
-
TendermintRequestUnSubscribe
-
Unsubscribe from event on Websocket
https://docs.tendermint.com/v0.34/rpc/#/Websocket/unsubscribe
-
TendermintRequestUnSubscribeAll
-
Unsubscribe from all events via WebSocket
https://docs.tendermint.com/v0.34/rpc/#/Websocket/unsubscribe_all
-
TendermintRequestValidators
-
Get validator set at a specified height
https://docs.tendermint.com/v0.34/rpc/#/Info/validators
-
TendermintStatus
-
-
TendermintSyncInfo
-
-
TendermintTxResponseResult
-
-
TendermintTxSearchResponseResult
-
-
TendermintTxSearchResponseResultTxs
-
-
TendermintTxSearchResponseResultTxsProof
-
-
TendermintTxSearchResponseResultTxsProofProof
-
-
TendermintUnconfirmedTransactionsResponseResult
-
-
TendermintValidator
-
-
TendermintValidatorInfo
-
-
TendermintValidatorPriority
-
-
TendermintValidatorPriorityPubKey
-
-
TendermintValidatorsResponseResult
-
-
ThorAsgardInboundAddressesResponse
-
-
ThorBanStatusResponse
-
-
ThorChainContractResponse
-
-
ThorCoinResponse
-
-
ThoreNodeQouteSwapFeeResponse
-
-
ThoreNodeQouteSwapResponse
-
-
ThorLatestBlockResponse
-
-
ThorNetworkStaticsResponse
-
-
ThorNodeMethods
-
-
ThorNodeNetworkConstants
-
-
ThorNodeProvider<SERVICE extends IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>>
-
Facilitates communication with the tendermint by making requests using a provided ThorNodeProvider.
-
ThorNodeRequesActiveMimirConfiguration
-
Returns current active mimir configuration.
-
ThorNodeRequesAdminMimirConfiguration
-
Returns current admin mimir configuration.
-
ThorNodeRequesKeyActiveMimirConfiguration
-
Returns current active mimir configuration for the provided key.
-
ThorNodeRequesPubkeyKeygenMetrics
-
Returns keygen metrics for the provided vault pubkey.
-
ThorNodeRequestAddressAssetLiquidityProviderInformation
-
Returns the liquidity provider information for an address and asset.
-
ThorNodeRequestAddressAssetSaverPosition
-
Returns the saver position given then savers pool and address.
-
ThorNodeRequestAddressBorrowerSaverPosition
-
Returns the borrower position given the pool and address.
-
ThorNodeRequestAddressCloutScore
-
Returns the clout score of an address
-
ThorNodeRequestAsgardInboundAddresses
-
Returns the set of asgard addresses that should be used for inbound transactions.
-
ThorNodeRequestAssetBorrowersInformation
-
Returns all borrowers for the given pool.
-
ThorNodeRequestAssetLiquidityProvidersInformation
-
Returns all liquidity provider information for an asset..
-
ThorNodeRequestAssetPoolInformation
-
Returns the pool information for the provided asset
-
ThorNodeRequestAssetSaversPosition
-
Returns all savers for the savers pool.
-
ThorNodeRequestBanStatus
-
Returns the ban status for the provided node address.
-
ThorNodeRequestBlock
-
Returns verbose details of the block.
-
ThorNodeRequestChainLatestBlock
-
Returns the last block information for the provided chain.
-
ThorNodeRequestConstants
-
Returns constant configuration, can be overridden by mimir.
-
ThorNodeRequestCurrentAsgardVaults
-
Returns current asgard vaults.
-
ThorNodeRequestCurrentYggdrasilVaults
-
Returns current yggdrasil vaults.
-
ThorNodeRequestDerivedAssetPoolInformation
-
Returns the pool information for the provided derived asset.
-
ThorNodeRequestDerivedPools
-
Returns the pool information for all derived assets.
-
ThorNodeRequestDetails
-
-
ThorNodeRequestGetTransaction
-
Returns the observed transaction for a provided inbound or outbound hash.
-
ThorNodeRequestGetTransactionDetails
-
Returns the signers for a provided inbound or outbound hash..
-
ThorNodeRequestGetTransactionStages
-
Returns the processing stages of a provided inbound hash
-
ThorNodeRequestGetTransactionStatus
-
Returns the observed transaction for a provided inbound or outbound hash.
-
ThorNodeRequestInvariant
-
Returns result of running the given invariant.
-
ThorNodeRequestInvariants
-
Returns a list of available invariants.
-
ThorNodeRequestKeysign
-
Returns keysign information for the provided height - the height being the first block a tx out item appears in the signed-but-unobserved outbound queue.
-
ThorNodeRequestLatestBlock
-
Returns the last block information for all chains.
-
ThorNodeRequestLoanCloseQuote
-
Provide a quote estimate for the provided loan close.
-
ThorNodeRequestLoanOpenQuote
-
Provide a quote estimate for the provided loan open.
-
ThorNodeRequestMetrics
-
Returns keygen and keysign metrics for current vaults.
-
ThorNodeRequestMimirV2
-
Returns current mimir V2 configuration.
-
ThorNodeRequestMimirV2Ids
-
Returns mapping of mimir V2 IDs to name.
-
ThorNodeRequestNetworkStatistics
-
Returns network overview statistics.
-
ThorNodeRequestNodeInformation
-
Returns node information for the provided node address.
-
ThorNodeRequestNodeMimirConfiguration
-
Returns current node mimir configuration for the provided node address.
-
ThorNodeRequestNodeMimirVotes
-
Returns current node mimir votes.
-
ThorNodeRequestNodesInformation
-
Returns node information for all registered validators.
-
ThorNodeRequestParam<RESULT, RESPONSE>
-
https://gateway.liquify.com/chain/thorchain_api/thorchain/doc/
An abstract class representing request parameters for tendermint API calls.
-
ThorNodeRequestPing
-
-
ThorNodeRequestPolStatics
-
Returns protocol owned liquidity overview statistics..
-
ThorNodeRequestPools
-
Returns the pool information for all assets.
-
ThorNodeRequestPubKeyKeysign
-
Returns keysign information for the provided height and pubkey -
the height being the block at which a tx out item is scheduled to
be signed and moved from the scheduled outbound queue to the outbound queue.
-
ThorNodeRequestPubkeyVault
-
Returns the vault for the provided pubkey.
-
ThorNodeRequestQueue
-
Returns all trade accounts for an asset
-
ThorNodeRequestQueueOutbound
-
-
ThorNodeRequestQueueScheduled
-
Returns the scheduled queue.
-
ThorNodeRequestQueueSwap
-
Returns the swap queue.
-
ThorNodeRequestRagnarok
-
Returns a boolean indicating whether the chain is in ragnarok.
-
ThorNodeRequestSaverDepositQuote
-
Provide a quote estimate for the provided saver deposit.
-
ThorNodeRequestSaverWithdrawQuote
-
Provide a quote estimate for the provided saver withdraw.
-
ThorNodeRequestStreamingSwapsState
-
Returns the state of all streaming swaps
-
ThorNodeRequestStreamingSwapState
-
Returns the state of a streaming swap
-
ThorNodeRequestSwapQuote
-
Provide a quote estimate for the provided swap.
-
ThorNodeRequestTradeAccount
-
Returns the units and depth of a trade account
-
ThorNodeRequestTradeAccounts
-
Returns all trade accounts for an asset
-
ThorNodeRequestTradeUnit
-
Returns the total units and depth of a trade asset
-
ThorNodeRequestTradeUnits
-
Returns the total units and depth for each trade asset
-
ThorNodeRequestVaultsPubkeys
-
Returns all pubkeys for current vaults.
-
ThorNodeRequestVersion
-
Returns the network's current THORNode version,
the network's next THORNode version, and the querier's THORNode version.
-
ThorQueueStatisticsResponse
-
-
ThorTradeAccountResponse
-
-
ThorVaultAddressInfoResponse
-
-
ThorVaultInfoResponse
-
-
ThorVaultPubkeysInfoResponse
-
-
ThorVersionResponse
-
-
VaultPubKeyInfo
-
Mixins
-
ChainRegistryServiceProvider
-
A mixin defining the service provider contract for interacting with the tendermint RPC.
-
CosmosQuickServiceApi<PROVIDER extends IProvider<IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, IServiceRequestParams>>
-
-
CosmosServiceProvider
-
A mixin defining the service provider contract for interacting with the tendermint RPC.
-
ThorNodeServiceProvider
-
A mixin defining the service provider contract for interacting with the thornode network.