sdk/provider/thornode/methods/methods library
Classes
- ThorNodeRequesActiveMimirConfiguration
- Returns current active mimir configuration.
- ThorNodeRequesAdminMimirConfiguration
- Returns current admin mimir configuration.
- ThorNodeRequesKeyActiveMimirConfiguration
- Returns current active mimir configuration for the provided key.
- ThorNodeRequesPubkeyKeygenMetrics
- Returns keygen metrics for the provided vault pubkey.
- ThorNodeRequestAddressAssetLiquidityProviderInformation
- Returns the liquidity provider information for an address and asset.
- ThorNodeRequestAddressAssetSaverPosition
- Returns the saver position given then savers pool and address.
- ThorNodeRequestAddressBorrowerSaverPosition
- Returns the borrower position given the pool and address.
- ThorNodeRequestAddressCloutScore
- Returns the clout score of an address
- ThorNodeRequestAsgardInboundAddresses
- Returns the set of asgard addresses that should be used for inbound transactions.
- ThorNodeRequestAssetBorrowersInformation
- Returns all borrowers for the given pool.
- ThorNodeRequestAssetLiquidityProvidersInformation
- Returns all liquidity provider information for an asset..
- ThorNodeRequestAssetPoolInformation
- Returns the pool information for the provided asset
- ThorNodeRequestAssetSaversPosition
- Returns all savers for the savers pool.
- ThorNodeRequestBanStatus
- Returns the ban status for the provided node address.
- ThorNodeRequestBlock
- Returns verbose details of the block.
- ThorNodeRequestChainLatestBlock
- Returns the last block information for the provided chain.
- ThorNodeRequestConstants
- Returns constant configuration, can be overridden by mimir.
- ThorNodeRequestCurrentAsgardVaults
- Returns current asgard vaults.
- ThorNodeRequestCurrentYggdrasilVaults
- Returns current yggdrasil vaults.
- ThorNodeRequestDerivedAssetPoolInformation
- Returns the pool information for the provided derived asset.
- ThorNodeRequestDerivedPools
- Returns the pool information for all derived assets.
- ThorNodeRequestGetTransaction
- Returns the observed transaction for a provided inbound or outbound hash.
- ThorNodeRequestGetTransactionDetails
- Returns the signers for a provided inbound or outbound hash..
- ThorNodeRequestGetTransactionStages
- Returns the processing stages of a provided inbound hash
- ThorNodeRequestGetTransactionStatus
- Returns the observed transaction for a provided inbound or outbound hash.
- ThorNodeRequestInvariant
- Returns result of running the given invariant.
- ThorNodeRequestInvariants
- Returns a list of available invariants.
- ThorNodeRequestKeysign
- Returns keysign information for the provided height - the height being the first block a tx out item appears in the signed-but-unobserved outbound queue.
- ThorNodeRequestLatestBlock
- Returns the last block information for all chains.
- ThorNodeRequestLoanCloseQuote
- Provide a quote estimate for the provided loan close.
- ThorNodeRequestLoanOpenQuote
- Provide a quote estimate for the provided loan open.
- ThorNodeRequestMetrics
- Returns keygen and keysign metrics for current vaults.
- ThorNodeRequestMimirV2
- Returns current mimir V2 configuration.
- ThorNodeRequestMimirV2Ids
- Returns mapping of mimir V2 IDs to name.
- ThorNodeRequestNetworkStatistics
- Returns network overview statistics.
- ThorNodeRequestNodeInformation
- Returns node information for the provided node address.
- ThorNodeRequestNodeMimirConfiguration
- Returns current node mimir configuration for the provided node address.
- ThorNodeRequestNodeMimirVotes
- Returns current node mimir votes.
- ThorNodeRequestNodesInformation
- Returns node information for all registered validators.
- ThorNodeRequestPing
- ThorNodeRequestPolStatics
- Returns protocol owned liquidity overview statistics..
- ThorNodeRequestPools
- Returns the pool information for all assets.
- ThorNodeRequestPubKeyKeysign
- Returns keysign information for the provided height and pubkey - the height being the block at which a tx out item is scheduled to be signed and moved from the scheduled outbound queue to the outbound queue.
- ThorNodeRequestPubkeyVault
- Returns the vault for the provided pubkey.
- ThorNodeRequestQueue
- Returns all trade accounts for an asset
- ThorNodeRequestQueueOutbound
- ThorNodeRequestQueueScheduled
- Returns the scheduled queue.
- ThorNodeRequestQueueSwap
- Returns the swap queue.
- ThorNodeRequestRagnarok
- Returns a boolean indicating whether the chain is in ragnarok.
- ThorNodeRequestSaverDepositQuote
- Provide a quote estimate for the provided saver deposit.
- ThorNodeRequestSaverWithdrawQuote
- Provide a quote estimate for the provided saver withdraw.
- ThorNodeRequestStreamingSwapsState
- Returns the state of all streaming swaps
- ThorNodeRequestStreamingSwapState
- Returns the state of a streaming swap
- ThorNodeRequestSwapQuote
- Provide a quote estimate for the provided swap.
- ThorNodeRequestTradeAccount
- Returns the units and depth of a trade account
- ThorNodeRequestTradeAccounts
- Returns all trade accounts for an asset
- ThorNodeRequestTradeUnit
- Returns the total units and depth of a trade asset
- ThorNodeRequestTradeUnits
- Returns the total units and depth for each trade asset
- ThorNodeRequestVaultsPubkeys
- Returns all pubkeys for current vaults.
- ThorNodeRequestVersion
- Returns the network's current THORNode version, the network's next THORNode version, and the querier's THORNode version.