ThorNodeRequestConstants class
Returns constant configuration, can be overridden by mimir.
- Inheritance
-
- Object
- BaseServiceRequest<
ThorNodeNetworkConstants, Map< String, dynamic> , ThorNodeRequestDetails> - ThorNodeRequestParam<
ThorNodeNetworkConstants, Map< String, dynamic> > - ThorNodeRequestConstants
Constructors
- ThorNodeRequestConstants({BigInt? height})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → BigInt?
-
optional block height, defaults to current tip
final
- method → String
-
method for the request.
no setteroverride
-
parameters
→ Map<
String, String?> -
no setteroverride
-
pathParameters
→ List<
String> -
list of path parameters variable
no setteroverride
- requestMethod → RequestMethod
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRequest(
int id) → ThorNodeRequestDetails -
Converts the request parameters to ThorNodeRequestDetails with a unique identifier.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onResonse(
Map< String, dynamic> result) → ThorNodeNetworkConstants -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited