ThorNodeRequestQueueSwap class

Returns the swap queue.

Inheritance

Constructors

ThorNodeRequestQueueSwap({BigInt? height})

Properties

hashCode int
The hash code for this object.
no setterinherited
height BigInt?
optional block height, defaults to current tip
final
method String
method for the request.
no setteroverride
parameters Map<String, String?>
no setteroverride
pathParameters List<String>
list of path parameters variable
no setteroverride
requestMethod → RequestMethod
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildRequest(int id) ThorNodeRequestDetails
Converts the request parameters to ThorNodeRequestDetails with a unique identifier.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onResonse(List<Map<String, dynamic>> result) List<Map<String, dynamic>>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited