PolStaticsResponse class

Constructors

PolStaticsResponse({required String runeDeposited, required String runeWithdrawn, required String value, required String pnl, required String currentDeposit})
const
PolStaticsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

currentDeposit String
final
hashCode int
The hash code for this object.
no setterinherited
pnl String
final
runeDeposited String
final
runeWithdrawn String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited