CosmosSerializationIdentifiers enum

Inheritance
Available extensions

Values

cosmosPluginError → const CosmosSerializationIdentifiers
const CosmosSerializationIdentifiers(19001)
aminoJsonParserError → const CosmosSerializationIdentifiers
const CosmosSerializationIdentifiers(19002)
thorNodeApiException → const CosmosSerializationIdentifiers
const CosmosSerializationIdentifiers(19003)
defaultTag → const CosmosSerializationIdentifiers
const CosmosSerializationIdentifiers(19004)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Identifier id must be grather than 258 for custom types.
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(int? tag) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CosmosSerializationIdentifiers>
A constant List of the values in this enum, in order of their declaration.