CosmosProtoMessage class abstract

Inheritance
  • Object
  • IProtoMessage
  • CosmosProtoMessage
Implementers

Constructors

CosmosProtoMessage()
const

Properties

declarationId CosmosProtoTypeUrl
no setter
hashCode int
The hash code for this object.
no setterinherited
protoValues List<Object?>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
inherited
toAny() Any
toBase64() String
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(List<int> bytes, ProtoMessageConfig config) → ProtoBufferDecoderResult