GovTextProposal class
TextProposal defines a standard text proposal whose changes need to be manually updated in case of approval.
- Inheritance
-
- Object
- CosmosProtocolBuffer
- CosmosMessage
- GovTextProposal
Constructors
- GovTextProposal({String? title, String? description})
-
const
-
GovTextProposal.deserialize(List<
int> bytes) -
factory
Properties
- description → String?
-
description associated with the proposal.
final
-
fieldIds
→ List<
int> -
List of field IDs corresponding to the values.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
title of the proposal.
final
- toHex → String
-
Gets the hexadecimal representation of the protocol buffer data.
no setterinherited
- typeUrl → String
-
no setteroverride
- values → List
-
List of dynamic values to be encoded.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAny(
) → Any -
inherited
-
toBuffer(
) → List< int> -
Converts the protocol buffer data to a byte buffer.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the data to a JSON representation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited