Redelegation class
Redelegation contains the list of a particular delegator's redelegating bonds from a particular source validator to a particular destination validator.
- Inheritance
-
- Object
- CosmosProtocolBuffer
- CosmosMessage
- Redelegation
Constructors
-
Redelegation({CosmosBaseAddress? delegatorAddress, CosmosBaseAddress? validatorSrcAddress, CosmosBaseAddress? validatorDstAddress, required List<
RedelegationEntry> entries}) -
Redelegation.deserialize(List<
int> bytes) -
factory
Properties
- delegatorAddress → CosmosBaseAddress?
-
delegator_address is the bech32-encoded address of the delegator.
final
-
entries
→ List<
RedelegationEntry> -
entries are the redelegation entries.
final
-
fieldIds
→ List<
int> -
List of field IDs corresponding to the values.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toHex → String
-
Gets the hexadecimal representation of the protocol buffer data.
no setterinherited
- typeUrl → String
-
no setteroverride
- validatorDstAddress → CosmosBaseAddress?
-
validator_dst_address is the validator redelegation destination operator address.
final
- validatorSrcAddress → CosmosBaseAddress?
-
validator_src_address is the validator redelegation source operator address.
final
- values → List
-
List of dynamic values to be encoded.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAny(
) → Any -
inherited
-
toBuffer(
) → List< int> -
Converts the protocol buffer data to a byte buffer.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the data to a JSON representation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited