SignerInfo class
SignerInfo describes the public key and signing mode of a single top-level signer.
- Inheritance
-
- Object
- CosmosProtocolBuffer
- CosmosMessage
- SignerInfo
Constructors
- SignerInfo({required CosmosPublicKeyInfo publicKey, required ModeInfo modeInfo, required BigInt sequence})
-
SignerInfo.deserialize(List<
int> bytes) -
factory
Properties
-
fieldIds
→ List<
int> -
List of field IDs corresponding to the values.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- modeInfo → ModeInfo
-
mode_info describes the signing mode of the signer and is a nested
structure to support nested multisig pubkey's
final
- publicKey → CosmosPublicKeyInfo
-
public_key is the public key of the signer. It is optional for accounts
that already exist in state. If unset, the verifier can use the required
signer address for this position and lookup the public key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → BigInt
-
sequence is the sequence of the account, which describes the
number of committed transactions signed by a given address. It is used to
prevent replay attacks.
final
- toHex → String
-
Gets the hexadecimal representation of the protocol buffer data.
no setterinherited
- typeUrl → String
-
no setteroverride
- values → List
-
List of dynamic values to be encoded.
no setteroverride
Methods
-
copyWith(
{CosmosPublicKeyInfo? publicKey, ModeInfo? modeInfo, BigInt? sequence}) → SignerInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAny(
) → Any -
inherited
-
toBuffer(
) → List< int> -
Converts the protocol buffer data to a byte buffer.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the data to a JSON representation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited