ServiceCommandDescriptor class
ServiceCommandDescriptor describes a CLI command based on a protobuf service.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- ServiceCommandDescriptor
Constructors
-
ServiceCommandDescriptor({String? service, List<
RpcCommandOptions> rpcCommandOptions = const [], Map<String, ServiceCommandDescriptor> subCommands = const {}, bool? enhanceCustomCommand, String? short}) -
const
-
ServiceCommandDescriptor.deserialize(List<
int> bytes) -
factory
-
ServiceCommandDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- enhanceCustomCommand → bool?
-
enhance_custom_commands specifies whether to skip the service when generating commands, if a custom command already
exists, or enhance the existing command. If set to true, the custom command will be enhanced with the services from
gRPC. otherwise when a custom command exists, no commands will be generated for the service.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protoValues
→ List<
Object?> -
no setteroverride
-
rpcCommandOptions
→ List<
RpcCommandOptions> -
rpc_command_options are options for commands generated from rpc methods.
If no options are specified for a given rpc method on the service, a
command will be generated for that method with the default options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String?
-
service is the fully qualified name of the protobuf service to build
the command from. It can be left empty if sub_commands are used instead
which may be the case if a module provides multiple tx and/or query services.
final
- short → String?
-
short is an optional parameter used to override the short description of the auto generated command.
final
-
subCommands
→ Map<
String, ServiceCommandDescriptor> -
sub_commands is a map of optional sub-commands for this command based on
different protobuf services. The map key is used as the name of the
sub-command.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig