InterfaceAcceptingMessageDescriptor class
InterfaceAcceptingMessageDescriptor describes a protobuf message which contains an interface represented as a google.protobuf.Any
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- InterfaceAcceptingMessageDescriptor
Constructors
-
InterfaceAcceptingMessageDescriptor({String? fullname, List<
String> fieldDescriptorNames = const []}) -
const
-
InterfaceAcceptingMessageDescriptor.deserialize(List<
int> bytes) -
factory
-
InterfaceAcceptingMessageDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
-
fieldDescriptorNames
→ List<
String> -
field_descriptor_names is a list of the protobuf name (not fullname) of the field
which contains the interface as google.protobuf.Any (the interface is the same, but
it can be in multiple fields of the same proto message)
final
- fullname → String?
-
fullname is the protobuf fullname of the type containing the interface
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig