QueryMethodDescriptor class
QueryMethodDescriptor describes a queryable method of a query service no other info is provided beside method name and tendermint queryable path because it would be redundant with the grpc reflection service
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryMethodDescriptor
Constructors
- QueryMethodDescriptor({String? name, String? fullQueryPath})
-
const
-
QueryMethodDescriptor.deserialize(List<
int> bytes) -
factory
-
QueryMethodDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- fullQueryPath → String?
-
full_query_path is the path that can be used to query
this method via tendermint abci.Query
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
name is the protobuf name (not fullname) of the method
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig