SigningModeDescriptor class
SigningModeDescriptor provides information on a signing flow of the application NOTE(fdymylja): here we could go as far as providing an entire flow on how to sign a message given a SigningModeDescriptor, but it's better to think about this another time
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- SigningModeDescriptor
Constructors
- SigningModeDescriptor({String? name, int? number, String? authnInfoProviderMethodFullname})
-
const
-
SigningModeDescriptor.deserialize(List<
int> bytes) -
factory
-
SigningModeDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- authnInfoProviderMethodFullname → String?
-
authn_info_provider_method_fullname defines the fullname of the method to call to get
the metadata required to authenticate using the provided sign_modes
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
name defines the unique name of the signing mode
final
- number → int?
-
number is the unique int32 identifier for the sign_mode enum
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig