TxDescriptor class
TxDescriptor describes the accepted transaction type
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- TxDescriptor
Constructors
-
TxDescriptor({String? fullname, List<
MsgDescriptor> msgs = const []}) -
const
-
TxDescriptor.deserialize(List<
int> bytes) -
factory
-
TxDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- fullname → String?
-
fullname is the protobuf fullname of the raw transaction type (for instance the tx.Tx type)
it is not meant to support polymorphism of transaction types, it is supposed to be used by
reflection clients to understand if they can handle a specific transaction type in an application.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
msgs
→ List<
MsgDescriptor> -
msgs lists the accepted application messages (sdk.Msg)
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig