QueryValidatorDistributionInfoResponse class
QueryValidatorDistributionInfoResponse is the response type for the Query/ValidatorDistributionInfo RPC method.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryValidatorDistributionInfoResponse
Constructors
-
QueryValidatorDistributionInfoResponse({String? operatorAddress, List<
DecCoin> selfBondRewards = const [], List<DecCoin> commission = const []}) -
const
-
QueryValidatorDistributionInfoResponse.deserialize(List<
int> bytes) -
factory
-
QueryValidatorDistributionInfoResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
commission
→ List<
DecCoin> -
commission defines the commission the validator received.
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- operatorAddress → String?
-
operator_address defines the validator operator address.
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selfBondRewards
→ List<
DecCoin> -
self_bond_rewards defines the self delegations rewards.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig