QueryAllowanceRequest class
QueryAllowanceRequest is the request type for the Query/Allowance RPC method.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryAllowanceRequest
- Mixed-in types
Constructors
- QueryAllowanceRequest({String? granter, String? grantee})
-
const
-
QueryAllowanceRequest.deserialize(List<
int> bytes) -
factory
-
QueryAllowanceRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- grantee → String?
-
grantee is the address of the user being granted an allowance of another user's funds.
final
- granter → String?
-
granter is the address of the user granting an allowance of their funds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onQueryResponse(
List< int> bytes) → QueryAllowanceResponse -
override
-
onQueryResponseJson(
Map< String, dynamic> json) → QueryAllowanceResponse -
override
-
protoConfig(
) → ProtoMessageConfig -
override
-
requestSpec(
) → HttpRequestSpec -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig