moduleName property
module_name is a field to query a specific module consensus version from state. Leaving this empty will fetch the full list of module versions from state
Implementation
final String? moduleName;
module_name is a field to query a specific module consensus version from state. Leaving this empty will fetch the full list of module versions from state
final String? moduleName;