Log class
Log represents an protobuf compatible Ethereum Log that defines a contract log event. These events are generated by the LOG opcode and stored/indexed by the node.
NOTE: address, topics and data are consensus fields. The rest of the fields are derived, i.e. filled in by the nodes, but not secured by consensus.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- Log
Constructors
Properties
- address → String?
-
address of the contract that generated the event
final
- blockHash → String?
-
block_hash of the block in which the transaction was included
final
- blockNumber → BigInt?
-
block_number of the block in which the transaction was included
final
-
data
→ List<
int> ? -
data which is supplied by the contract, usually ABI-encoded
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → BigInt?
-
index of the log in the block
final
-
protoValues
→ List<
Object?> -
no setteroverride
- removed → bool?
-
removed is true if this log was reverted due to a chain
reorganisation. You must pay attention to this field if you receive logs
through a filter query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topics
→ List<
String> -
topics is a list of topics provided by the contract.
final
- txHash → String?
-
tx_hash is the transaction hash
final
- txIndex → BigInt?
-
tx_index of the transaction in the block
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig