TraceConfig class
TraceConfig holds extra parameters to trace functions.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- TraceConfig
Constructors
- TraceConfig({String? tracer, String? timeout, BigInt? reexec, bool? disableStack, bool? disableStorage, bool? debug, int? limit, ChainConfig? overrides, bool? enableMemory, bool? enableReturnData, String? tracerJsonConfig})
-
const
-
TraceConfig.deserialize(List<
int> bytes) -
factory
-
TraceConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- debug → bool?
-
debug can be used to print output during capture end
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- disableStack → bool?
-
disable_stack switches stack capture
final
- disableStorage → bool?
-
disable_storage switches storage capture
final
- enableMemory → bool?
-
enable_memory switches memory capture
final
- enableReturnData → bool?
-
enable_return_data switches the capture of return data
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
limit defines the maximum length of output, but zero means unlimited
final
- overrides → ChainConfig?
-
overrides can be used to execute a trace using future fork rules
final
-
protoValues
→ List<
Object?> -
no setteroverride
- reexec → BigInt?
-
reexec defines the number of blocks the tracer is willing to go back
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → String?
-
timeout overrides the default timeout of 5 seconds for JavaScript-based tracing
calls
final
- tracer → String?
-
DEPRECATED: DisableMemory and DisableReturnData have been renamed to
Enable*.
tracer is a custom javascript tracer
final
- tracerJsonConfig → String?
-
tracer_json_config configures the tracer using a JSON string
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig