EthCallRequest class
EthCallRequest defines EthCall request
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- EthCallRequest
- Mixed-in types
Constructors
-
EthCallRequest({List<
int> ? args, BigInt? gasCap, List<int> ? proposerAddress, BigInt? chainId}) -
const
-
EthCallRequest.deserialize(List<
int> bytes) -
factory
-
EthCallRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
args
→ List<
int> ? -
args uses the same json format as the json rpc api.
final
- chainId → BigInt?
-
chain_id is the eip155 chain id parsed from the requested block header
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- gasCap → BigInt?
-
gas_cap defines the default gas cap to be used
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
proposerAddress
→ List<
int> ? -
proposer_address of the requested block in hex format
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onQueryResponse(
List< int> bytes) → MsgEthereumTxResponse -
override
-
onQueryResponseJson(
Map< String, dynamic> json) → MsgEthereumTxResponse -
override
-
protoConfig(
) → ProtoMessageConfig -
override
-
requestSpec(
) → HttpRequestSpec -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig