predecessors property
predecessors is an array of transactions included in the same block need to be replayed first to get correct context for tracing.
Implementation
final List<ethermint_evm_v1_tx.MsgEthereumTx> predecessors;
predecessors is an array of transactions included in the same block need to be replayed first to get correct context for tracing.
final List<ethermint_evm_v1_tx.MsgEthereumTx> predecessors;