proto_messages/google/protobuf/models
library
Classes
-
DescriptorProto
-
Describes a message type.
-
DescriptorProtoExtensionRange
-
-
DescriptorProtoReservedRange
-
Range of reserved tag numbers. Reserved tag numbers may not be used by
fields or extension ranges in the same message. Reserved ranges may
not overlap.
-
Duration
-
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc. All rights reserved.
https://developers.google.com/protocol-buffers/
-
Empty
-
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc. All rights reserved.
https://developers.google.com/protocol-buffers/
-
EnumDescriptorProto
-
Describes an enum type.
-
EnumDescriptorProtoEnumReservedRange
-
Range of reserved numeric values. Reserved values may not be used by
entries in the same enum. Reserved ranges may not overlap.
-
EnumOptions
-
Clients can define custom options in extensions of this message. See above.
-
EnumValueDescriptorProto
-
Describes a value within an enum.
-
EnumValueOptions
-
Clients can define custom options in extensions of this message. See above.
-
ExtensionRangeOptions
-
-
ExtensionRangeOptionsDeclaration
-
-
FeatureSet
-
===================================================================
Features
not well scoped. This means that each of the feature enums below can clash
with each other. The short names we've chosen maximize call-site
readability, but leave us very open to this scenario. A future feature will
be designed and implemented to handle this, hopefully before we ever hit a
conflict here.
-
FieldDescriptorProto
-
Clients can define custom options in extensions of this message. See above.
Describes a field within a message.
-
FieldOptions
-
Clients can define custom options in extensions of this message. See above.
-
FieldOptionsEditionDefault
-
-
FieldOptionsFeatureSupport
-
Information about the support window of a feature.
-
FileDescriptorProto
-
Describes a complete .proto file.
-
FileOptions
-
===================================================================
Options
Each of the definitions above may have "options" attached. These are
just annotations which may cause code to be generated slightly differently
or may contain hints for code that manipulates protocol messages.
-
MessageOptions
-
Clients can define custom options in extensions of this message.
See the documentation for the "Options" section above.
-
MethodDescriptorProto
-
Describes a method of a service.
-
MethodOptions
-
Clients can define custom options in extensions of this message. See above.
-
OneofDescriptorProto
-
Describes a oneof.
-
OneofOptions
-
Clients can define custom options in extensions of this message. See above.
removed jtype
reserve target, target_obsolete_do_not_use
-
ServiceDescriptorProto
-
Describes a service.
-
ServiceOptions
-
Clients can define custom options in extensions of this message. See above.
-
SourceCodeInfo
-
===================================================================
Optional source code info
Encapsulates information about the original source file from which a
FileDescriptorProto was generated.
-
SourceCodeInfoLocation
-
-
Timestamp
-
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc. All rights reserved.
https://developers.google.com/protocol-buffers/
-
UninterpretedOption
-
Clients can define custom options in extensions of this message. See above.
A message representing a option the parser does not recognize. This only
appears in options protos created by the compiler::Parser class.
DescriptorPool resolves these when building Descriptor objects. Therefore,
options protos in descriptor objects (e.g. returned by Descriptor::options(),
or produced by Descriptor::CopyTo()) will never have UninterpretedOptions
in them.
-
UninterpretedOptionNamePart
-
The name of the uninterpreted option. Each string represents a segment in
a dot-separated name. is_extension is true iff a segment represents an
extension (denoted with parentheses in options specs in .proto files).
E.g.,{
"foo", false, "bar.baz", true, "moo", false } represents
"foo.(bar.baz).moo".