ExtensionRangeOptionsDeclaration class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- ExtensionRangeOptionsDeclaration
Constructors
- ExtensionRangeOptionsDeclaration({int? number, String? fullName, String? type, bool? reserved, bool? repeated})
-
const
-
ExtensionRangeOptionsDeclaration.deserialize(List<
int> bytes) -
factory
-
ExtensionRangeOptionsDeclaration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- fullName → String?
-
The fully-qualified name of the extension field. There must be a leading
dot in front of the full name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- number → int?
-
The extension number declared within the extension range.
final
-
protoValues
→ List<
Object?> -
no setteroverride
- repeated → bool?
-
If true, indicates that the extension must be defined as repeated.
Otherwise the extension must be defined as optional.
final
- reserved → bool?
-
If true, indicates that the number is reserved in the extension range,
and any extension field with the number will fail to compile. Set this
when a declared extension field is deleted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
The fully-qualified type name of the extension field. Unlike
Metadata.type, Declaration.type must have a leading dot for messages
and enums.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig