FeatureSet class

=================================================================== Features not well scoped. This means that each of the feature enums below can clash with each other. The short names we've chosen maximize call-site readability, but leave us very open to this scenario. A future feature will be designed and implemented to handle this, hopefully before we ever hit a conflict here.

Inheritance

Constructors

FeatureSet({FeatureSetFieldPresence? fieldPresence, FeatureSetEnumType? enumType, FeatureSetRepeatedFieldEncoding? repeatedFieldEncoding, FeatureSetUtf8Validation? utf8Validation, FeatureSetMessageEncoding? messageEncoding, FeatureSetJsonFormat? jsonFormat, FeatureSetEnforceNamingStyle? enforceNamingStyle, FeatureSetVisibilityFeatureDefaultSymbolVisibility? defaultSymbolVisibility})
const
FeatureSet.deserialize(List<int> bytes)
factory
FeatureSet.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
defaultSymbolVisibility FeatureSetVisibilityFeatureDefaultSymbolVisibility?
final
enforceNamingStyle FeatureSetEnforceNamingStyle?
final
enumType FeatureSetEnumType?
final
fieldPresence FeatureSetFieldPresence?
final
hashCode int
The hash code for this object.
no setterinherited
jsonFormat FeatureSetJsonFormat?
final
messageEncoding FeatureSetMessageEncoding?
final
protoValues List<Object?>
no setteroverride
repeatedFieldEncoding FeatureSetRepeatedFieldEncoding?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utf8Validation FeatureSetUtf8Validation?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig