FieldDescriptorProtoLabel enum
Uses ZigZag encoding.
Values
- labelOptional → const FieldDescriptorProtoLabel
-
0 is reserved for errors
const FieldDescriptorProtoLabel(1, 'LABEL_OPTIONAL') - labelRepeated → const FieldDescriptorProtoLabel
-
const FieldDescriptorProtoLabel(3, 'LABEL_REPEATED') - labelRequired → const FieldDescriptorProtoLabel
-
The required label is only allowed in google.protobuf. In proto3 and Editions it's explicitly prohibited. In Editions, the
field_presencefeature can be used to get this behavior.const FieldDescriptorProtoLabel(2, 'LABEL_REQUIRED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - protoName → String
-
The original proto identifier, e.g. "VOTE_OPTION_UNSPECIFIED".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The original proto wire value for this enum constant.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from(
Object? value) → FieldDescriptorProtoLabel -
Looks up a value by wire int, Dart enum name, or original proto
name (whichever
valuehappens to be). Throws if not found. -
fromValue(
int? value) → FieldDescriptorProtoLabel - Looks up a value by its proto wire int. Throws if not found.
Constants
-
values
→ const List<
FieldDescriptorProtoLabel> - A constant List of the values in this enum, in order of their declaration.