FileDescriptorProto class

Describes a complete .proto file.

Inheritance

Constructors

FileDescriptorProto({String? name, String? package, List<String> dependency = const [], List<int> publicDependency = const [], List<int> weakDependency = const [], List<String> optionDependency = const [], List<DescriptorProto> messageType = const [], List<EnumDescriptorProto> enumType = const [], List<ServiceDescriptorProto> service = const [], List<FieldDescriptorProto> extension_ = const [], FileOptions? options, SourceCodeInfo? sourceCodeInfo, String? syntax, Edition? edition})
const
FileDescriptorProto.deserialize(List<int> bytes)
factory
FileDescriptorProto.fromJson(Map<String, dynamic> json)
factory

Properties

declarationId DefaultCosmosProtoTypeUrl
no setteroverride
dependency List<String>
e.g. "foo", "foo.bar", etc. Names of files imported by this file.
final
edition Edition?
The edition of the proto file. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.
final
enumType List<EnumDescriptorProto>
final
extension_ List<FieldDescriptorProto>
final
hashCode int
The hash code for this object.
no setterinherited
messageType List<DescriptorProto>
All top-level definitions in this file.
final
name String?
final
optionDependency List<String>
Names of files imported by this file purely for the purpose of providing option extensions. These are excluded from the dependency list above.
final
options FileOptions?
final
package String?
file name, relative to root of source tree
final
protoValues List<Object?>
no setteroverride
publicDependency List<int>
Indexes of the public imported files in the dependency list above.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service List<ServiceDescriptorProto>
final
sourceCodeInfo SourceCodeInfo?
This field contains optional information about the original source code. You may safely remove this entire field without harming runtime functionality of the descriptors -- the information is needed only by development tools.
final
syntax String?
The syntax of the proto file. The supported values are "proto2", "proto3", and "editions".
final
weakDependency List<int>
Indexes of the weak imported files in the dependency list. For Google-internal migration only. Do not use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
protoConfig() → ProtoMessageConfig
override
toAny() Any
inherited
toBase64() String
inherited
toBuffer() List<int>
inherited
toJson() Map<String, dynamic>
Dont change order of toJson the key index must be equal to protoConfig fields.
override
toJsonObject(CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

protoConfigStatic() → ProtoMessageConfig