objcClassPrefix property
Sets the objective c class prefix which is prepended to all objective c generated classes from this .proto. There is no default.
Implementation
final String? objcClassPrefix;
Sets the objective c class prefix which is prepended to all objective c generated classes from this .proto. There is no default.
final String? objcClassPrefix;