phpNamespace property

String? phpNamespace
final

Use this option to change the namespace of php generated classes. Default is empty. When this option is empty, the package name will be used for determining the namespace.

Implementation

final String? phpNamespace;