SourceCodeInfoLocation class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- SourceCodeInfoLocation
Constructors
-
SourceCodeInfoLocation({List<
int> path = const [], List<int> span = const [], String? leadingComments, String? trailingComments, List<String> leadingDetachedComments = const []}) -
const
-
SourceCodeInfoLocation.deserialize(List<
int> bytes) -
factory
-
SourceCodeInfoLocation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- leadingComments → String?
-
If this SourceCodeInfo represents a complete declaration, these are any
comments appearing before and after the declaration which appear to be
attached to the declaration.
final
-
leadingDetachedComments
→ List<
String> -
final
-
path
→ List<
int> -
Identifies which part of the FileDescriptorProto was defined at this
location.
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
span
→ List<
int> -
Always has exactly three or four elements: start line, start column,
end line (optional, otherwise assumed same as start line), end column.
These are packed into a single field for efficiency. Note that line
and column numbers are zero-based -- typically you will want to add
1 to each before displaying to a user.
final
- trailingComments → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig