StreamResponse class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- StreamResponse
Constructors
-
StreamResponse({BigInt? blockHeight, BigInt? blockTime, List<
BankBalance> bankBalances = const [], List<SubaccountDeposits> subaccountDeposits = const [], List<SpotTrade> spotTrades = const [], List<DerivativeTrade> derivativeTrades = const [], List<SpotOrderUpdate> spotOrders = const [], List<DerivativeOrderUpdate> derivativeOrders = const [], List<OrderbookUpdate> spotOrderbookUpdates = const [], List<OrderbookUpdate> derivativeOrderbookUpdates = const [], List<Position> positions = const [], List<OraclePrice> oraclePrices = const [], String? gasPrice, List<OrderFailureUpdate> orderFailures = const [], List<ConditionalOrderTriggerFailureUpdate> conditionalOrderTriggerFailures = const []}) -
const
-
StreamResponse.deserialize(List<
int> bytes) -
factory
-
StreamResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
bankBalances
→ List<
BankBalance> -
list of bank balances updates
final
- blockHeight → BigInt?
-
the block height
final
- blockTime → BigInt?
-
the block time
final
-
conditionalOrderTriggerFailures
→ List<
ConditionalOrderTriggerFailureUpdate> -
list of conditional order trigger failures updates
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
-
derivativeOrderbookUpdates
→ List<
OrderbookUpdate> -
list of derivative orderbook updates
final
-
derivativeOrders
→ List<
DerivativeOrderUpdate> -
list of derivative orders updates
final
-
derivativeTrades
→ List<
DerivativeTrade> -
list of derivative trades updates
final
- gasPrice → String?
-
the current gas price when the block was processed (in chain format)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
oraclePrices
→ List<
OraclePrice> -
list of oracle prices updates
final
-
orderFailures
→ List<
OrderFailureUpdate> -
list of order failures updates
final
-
positions
→ List<
Position> -
list of positions updates
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spotOrderbookUpdates
→ List<
OrderbookUpdate> -
list of spot orderbook updates
final
-
spotOrders
→ List<
SpotOrderUpdate> -
list of spot orders updates
final
-
spotTrades
→ List<
SpotTrade> -
list of spot trades updates
final
-
subaccountDeposits
→ List<
SubaccountDeposits> -
list of subaccount deposits updates
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig