QueryCondition class
QueryCondition is a struct used for querying locks upon different conditions. Duration field and timestamp fields could be optional, depending on the LockQueryType.
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryCondition
Constructors
- QueryCondition({LockQueryType? lockQueryType, String? denom, Duration? duration, Timestamp? timestamp})
-
const
-
QueryCondition.deserialize(List<
int> bytes) -
factory
-
QueryCondition.fromJson(Map<
String, dynamic> json) -
factory
Properties
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- denom → String?
-
Denom represents the token denomination we are looking to lock up
final
- duration → Duration?
-
Duration is used to query locks with longer duration than the specified
duration. Duration field must not be nil when the lock query type is
ByLockDuration.final - hashCode → int
-
The hash code for this object.
no setterinherited
- lockQueryType → LockQueryType?
-
LockQueryType is a type of lock query, ByLockDuration | ByLockTime
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → Timestamp?
-
Timestamp is used by locks started before the specified duration.
Timestamp field must not be nil when the lock query type is
ByLockTime. Querying locks with timestamp is currently not implemented.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig