QueryUserSummaryResponse class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- QueryUserSummaryResponse
Constructors
- QueryUserSummaryResponse({String? claimType, String? claimed, String? forfeited, String? remaining, String? claimable})
-
const
-
QueryUserSummaryResponse.deserialize(List<
int> bytes) -
factory
-
QueryUserSummaryResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- claimable → String?
-
The total rewards that can be claimed right now
final
- claimed → String?
-
The total rewards claimed so far
final
- claimType → String?
-
The claim type (claim daily or claim early)
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- forfeited → String?
-
The total rewards forfeited (in the case of claiming early)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protoValues
→ List<
Object?> -
no setteroverride
- remaining → String?
-
The total rewards remaining
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig