MsgCreateAuction class
MsgCreateAuction defines the message for adding a token auction
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- MsgCreateAuction
- Mixed-in types
Constructors
- MsgCreateAuction({String? admin, String? auctionName, AuctionType? auctionType, String? sellingDenom, String? paymentDenom, bool? enabled, String? minPriceMultiplier, String? minBidAmount, String? beneficiary})
-
const
-
MsgCreateAuction.deserialize(List<
int> bytes) -
factory
-
MsgCreateAuction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- admin → String?
-
Admin's address
final
- auctionName → String?
-
A unique auction name
final
- auctionType → AuctionType?
-
Auction type
final
- beneficiary → String?
-
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- enabled → bool?
-
Whether auction is active
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minBidAmount → String?
-
Minimum payment token bid amount
final
- minPriceMultiplier → String?
-
Minimum price multiplier (e.g. 0.95 for 5% discount off the oracle price)
bids_floor_price = oracle_price * min_price_multiplier
final
- paymentDenom → String?
-
Denom on Stride of the token being used to place bids (e.g. "ustrd")
final
-
protoValues
→ List<
Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sellingDenom → String?
-
Denom on Stride of the token being auctioned off (e.g. "ibc/...")
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onServiceResponse(
List< int> bytes) → MsgCreateAuctionResponse -
override
-
onServiceResponseJson(
Map< String, dynamic> json) → MsgCreateAuctionResponse -
override
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAminoJson(
{CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig