Query class
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- Query
Constructors
-
Query({String? id, String? connectionId, String? chainId, String? queryType, List<
int> ? requestData, String? callbackModule, String? callbackId, List<int> ? callbackData, TimeoutPolicy? timeoutPolicy, Duration? timeoutDuration, BigInt? timeoutTimestamp, bool? requestSent, BigInt? submissionHeight}) -
const
-
Query.deserialize(List<
int> bytes) -
factory
-
Query.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
callbackData
→ List<
int> ? -
final
- callbackId → String?
-
final
- callbackModule → String?
-
final
- chainId → String?
-
final
- connectionId → String?
-
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
-
protoValues
→ List<
Object?> -
no setteroverride
- queryType → String?
-
final
-
requestData
→ List<
int> ? -
final
- requestSent → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submissionHeight → BigInt?
-
final
- timeoutDuration → Duration?
-
final
- timeoutPolicy → TimeoutPolicy?
-
final
- timeoutTimestamp → BigInt?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig