Params class
Params defines the parameters for the module. next id: 20
- Inheritance
-
- Object
- IProtoMessage
- CosmosProtoMessage
- Params
Constructors
- Params({BigInt? rewardsInterval, BigInt? delegateInterval, BigInt? depositInterval, BigInt? redemptionRateInterval, BigInt? strideCommission, BigInt? reinvestInterval, BigInt? icaTimeoutNanos, BigInt? bufferSize, BigInt? ibcTimeoutBlocks, BigInt? feeTransferTimeoutNanos, BigInt? maxStakeIcaCallsPerEpoch, BigInt? defaultMinRedemptionRateThreshold, BigInt? defaultMaxRedemptionRateThreshold, BigInt? ibcTransferTimeoutNanos, BigInt? validatorSlashQueryThreshold, BigInt? validatorWeightCap})
-
const
-
Params.deserialize(List<
int> bytes) -
factory
-
Params.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bufferSize → BigInt?
-
final
- declarationId → DefaultCosmosProtoTypeUrl
-
no setteroverride
- defaultMaxRedemptionRateThreshold → BigInt?
-
final
- defaultMinRedemptionRateThreshold → BigInt?
-
final
- delegateInterval → BigInt?
-
final
- depositInterval → BigInt?
-
final
- feeTransferTimeoutNanos → BigInt?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ibcTimeoutBlocks → BigInt?
-
final
- ibcTransferTimeoutNanos → BigInt?
-
final
- icaTimeoutNanos → BigInt?
-
final
- maxStakeIcaCallsPerEpoch → BigInt?
-
final
-
protoValues
→ List<
Object?> -
no setteroverride
- redemptionRateInterval → BigInt?
-
final
- reinvestInterval → BigInt?
-
final
- rewardsInterval → BigInt?
-
define epoch lengths, in stride_epochs
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strideCommission → BigInt?
-
final
- validatorSlashQueryThreshold → BigInt?
-
final
- validatorWeightCap → BigInt?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
protoConfig(
) → ProtoMessageConfig -
override
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to protoConfig fields.
override
-
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
protoConfigStatic(
) → ProtoMessageConfig