CosmosBaseAddress class
This class represents a base address in the Cosmos network.
- Mixed-in types
-
- Equality
- CborTagSerializable
Constructors
- CosmosBaseAddress(String addr, {String? forceHrp})
-
Factory constructor to create a CosmosBaseAddress from a string.
factory
-
CosmosBaseAddress.deserializeIAddress({List<
int> ? bytes, CborObject<Object?> ? object}) -
factory
-
CosmosBaseAddress.fromBytes(List<
int> addrBytes, {String hrp = CosmosAddrConst.accHRP}) -
Factory constructor to create a CosmosBaseAddress from byte data.
factory
-
CosmosBaseAddress.fromPublicKey({required List<
int> pubkeyBytes, required CosmosKeysAlgs algorithm, String hrp = CosmosAddrConst.accHRP}) -
Factory constructor to create a CosmosBaseAddress from public key and algorithm.
factory
-
CosmosBaseAddress.module(String moduleName, {List<
List< derivationKeys = const [], String hrp = CosmosAddrConst.accHRP})int> > -
Module is a specialized version of a composed address for modules. Each module account
is constructed from a module name and a sequence of derivation keys (at least one
derivation key must be provided). The derivation keys must be unique
in the module scope, and is usually constructed from some object id. Example, let's
a x/dao module, and a new DAO object.
factory
Properties
- address → String
-
The raw address string.
final
- blockchainNetwork → BlockchainNetwork
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hrp → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializationIdentifier → SerializationIdentifier
-
no setteroverride
-
serializationItems
→ List<
CborObject< Object?> ?> -
no setteroverride
- variables → List
-
no setteroverride
- viewType → String?
-
the specefic type of address in network like (Primary address monero)
no setteroverride
Methods
-
encodeAsIAddress(
) → List< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> -
toCbor(
) → CborTagValue< CborObject< Object?> > -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited