TendermintMethods class
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- abciInfo → const TendermintMethods
- Get info about the application.
- abciQuery → const TendermintMethods
- Query the application for some information.
- block → const TendermintMethods
- Get block at a specified height
- blockByHash → const TendermintMethods
- Get block by hash
- blockchain → const TendermintMethods
- Get block headers for minHeight <= height <= maxHeight.
- blockResult → const TendermintMethods
- Get block results at a specified height
- blockSearch → const TendermintMethods
- Search for blocks by BeginBlock and EndBlock events
- broadcastEvidence → const TendermintMethods
- Broadcast evidence of the misbehavior.
- broadcastTxAsync → const TendermintMethods
- Returns right away, with no response. Does not wait for CheckTx nor DeliverTx results.
- broadcastTxCommit → const TendermintMethods
- Returns with the responses from CheckTx and DeliverTx.
- broadcastTxSync → const TendermintMethods
- Returns with the response from CheckTx. Does not wait for DeliverTx result.
- checkTx → const TendermintMethods
- Checks the transaction without executing it.
- commit → const TendermintMethods
- Get commit results at a specified height
- consensusParams → const TendermintMethods
- Get consensus parameters
- consensusState → const TendermintMethods
- Get consensus state
- dialPeers → const TendermintMethods
- Add Peers/Persistent Peers
- dialSeeds → const TendermintMethods
- Dial a peer, this route in under unsafe, and has to manually enabled to use
- dumpConsensusState → const TendermintMethods
- Get consensus state
- genesis → const TendermintMethods
- Get Genesis
- genesisChunked → const TendermintMethods
- Get Genesis in multiple chunks
- health → const TendermintMethods
- Get node health. Returns empty result (200 OK) on success, no response - in case of an error.
- netInfo → const TendermintMethods
- Network informations
- numUnconfirmedTxs → const TendermintMethods
- Get data about unconfirmed transactions
- removeTx → const TendermintMethods
- status → const TendermintMethods
- Get Tendermint status including node info, pubkey, latest block hash, app hash, block height and time.
- subscribe → const TendermintMethods
- Subscribe for events via WebSocket.
- tx → const TendermintMethods
- Get a transaction
- txSearch → const TendermintMethods
- Search for transactions
- unconfirmedTxs → const TendermintMethods
- Get the list of unconfirmed transactions
- unsubscribe → const TendermintMethods
- Unsubscribe from event on Websocket
- unsubscribeAll → const TendermintMethods
- Unsubscribe from all events via WebSocket
- validators → const TendermintMethods
- Get validator set at a specified height