CosmosRestRequestMessage<Response extends CosmosProtoMessage> class

Inheritance

Constructors

CosmosRestRequestMessage({required ICosmosProtoQueryMessage<Response> request})

Properties

body Map<String, dynamic>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, dynamic>
no setteroverride
path String
method for the request.
no setteroverride
request ICosmosProtoQueryMessage<Response>
final
requestMethod → RequestMethod
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec → HttpRequestSpec
final

Methods

buildRequest(int id) CosmosRestRequestDetails
Converts the request parameters to TendermintRequestDetails with a unique identifier.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onResonse(Map<String, dynamic> result) → Response
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited