ThorNodeRequestGetTransactionStatus class
Returns the observed transaction for a provided inbound or outbound hash.
- Inheritance
-
- Object
- BaseServiceRequest<
TxStatusResponse, Map< String, dynamic> , ThorNodeRequestDetails> - ThorNodeRequestParam<
TxStatusResponse, Map< String, dynamic> > - ThorNodeRequestGetTransactionStatus
Constructors
- ThorNodeRequestGetTransactionStatus({required String hash, BigInt? height})
Properties
- hash → String
-
Example: CF524818D42B63D25BBA0CCC4909F127CAA645C0F9CD07324F2824CC151A64C7
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → BigInt?
-
optional block height, defaults to current tip
final
- method → String
-
method for the request.
no setteroverride
-
parameters
→ Map<
String, String?> -
no setteroverride
-
pathParameters
→ List<
String> -
list of path parameters variable
no setteroverride
- requestMethod → RequestMethod
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRequest(
int id) → ThorNodeRequestDetails -
Converts the request parameters to ThorNodeRequestDetails with a unique identifier.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onResonse(
Map< String, dynamic> result) → TxStatusResponse -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited