ThorQueueStatisticsResponse class

Constructors

ThorQueueStatisticsResponse({required int swap, required int outbound, required int internal, required String scheduledOutboundValue, required String scheduledOutboundClout})
const
ThorQueueStatisticsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
internal int
final
outbound int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledOutboundClout String
final
scheduledOutboundValue String
final
swap int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited