ICosmosProtoServiceMessage<RESPONSE extends CosmosProtoMessage> mixin
- Superclass constraints
- Mixin applications
-
- MsgAcceptOwner
- MsgAcknowledgement
- MsgAcknowledgement
- MsgActivateContract
- MsgActivateEmergencyProposal
- MsgActivatePostOnlyMode
- MsgActivateStakeGrant
- MsgActivateStakeGrant
- MsgAddAllocations
- MsgAddAttestor
- MsgAddAuthenticator
- MsgAddBridgeExecutor
- MsgAddClaimRecords
- MsgAddCodeUploadParamsAddresses
- MsgAddEmergencySubmitters
- MsgAddFeeWhitelistAddresses
- MsgAddMission
- MsgAddOracle
- MsgAddRemoteTokenMessenger
- MsgAddSchedule
- MsgAddToConcentratedLiquiditySuperfluidPosition
- MsgAddToGauge
- MsgAddToPosition
- MsgAddValidators
- MsgAdjustDelegatedBalance
- MsgAdjustDelegatedBalance
- MsgAdminUpdateBinaryOptionsMarket
- MsgAdminUpdateBinaryOptionsMarket
- MsgApproveUpgrade
- MsgAtomicMarketOrderFeeMultiplierSchedule
- MsgAuthorizeStakeGrants
- MsgAuthorizeStakeGrants
- MsgBan
- MsgBatchCancelBinaryOptionsOrders
- MsgBatchCancelBinaryOptionsOrders
- MsgBatchCancelDerivativeOrders
- MsgBatchCancelDerivativeOrders
- MsgBatchCancelSpotOrders
- MsgBatchCancelSpotOrders
- MsgBatchCommunityPoolSpend
- MsgBatchCreateDerivativeLimitOrders
- MsgBatchCreateDerivativeLimitOrders
- MsgBatchCreateSpotLimitOrders
- MsgBatchCreateSpotLimitOrders
- MsgBatchExchangeModification
- MsgBatchExchangeModification
- MsgBatchLiquidatePositions
- MsgBatchUpdateOrders
- MsgBatchUpdateOrders
- MsgBeginRedelegate
- MsgBeginRedelegate
- MsgBeginUnlocking
- MsgBeginUnlockingAll
- MsgBid
- MsgBinaryOptionsMarketLaunch
- MsgBinaryOptionsMarketParamUpdate
- MsgBlacklistEthereumAddresses
- MsgBurn
- MsgBurn
- MsgBurn
- MsgBurn
- MsgBurnTokens
- MsgCalibrateDelegation
- MsgCancelBinaryOptionsOrder
- MsgCancelBinaryOptionsOrder
- MsgCancelContinuousFund
- MsgCancelDerivativeOrder
- MsgCancelDerivativeOrder
- MsgCancelPostOnlyMode
- MsgCancelProposal
- MsgCancelSendToEth
- MsgCancelSpotOrder
- MsgCancelSpotOrder
- MsgCancelUnbondingDelegation
- MsgCancelUnbondingDelegation
- MsgCancelUpgrade
- MsgChangeAdmin
- MsgChangeAdmin
- MsgChangeDenomAdmin
- MsgChangeValidatorWeights
- MsgChannelCloseConfirm
- MsgChannelCloseInit
- MsgChannelOpenAck
- MsgChannelOpenConfirm
- MsgChannelOpenInit
- MsgChannelOpenTry
- MsgClaim
- MsgClaimDaily
- MsgClaimEarly
- MsgClaimFreeAmount
- MsgClaimUndelegatedTokens
- MsgClaimVoucher
- MsgClaimVoucher
- MsgClaimVoucher
- MsgClawback
- MsgClearAdmin
- MsgClearAdmin
- MsgClearBalance
- MsgCloseCampaign
- MsgCloseDelegationChannel
- MsgCollectIncentives
- MsgCollectSpreadRewards
- MsgCommunityPoolSpend
- MsgCommunityPoolSpend
- MsgConfirmBatch
- MsgConfirmDelegation
- MsgConfirmDelegation
- MsgConfirmUnbondedTokenSweep
- MsgConfirmUnbondedTokenSweep
- MsgConfirmUndelegation
- MsgConfirmUndelegation
- MsgConnectionOpenAck
- MsgConnectionOpenConfirm
- MsgConnectionOpenInit
- MsgConnectionOpenTry
- MsgContractGovernanceProposal
- MsgConvertCoin
- MsgConvertERC20
- MsgConvertERC20
- MsgConvertVestingAccount
- MsgCreateAirdrop
- MsgCreateAirdrop
- MsgCreateAuction
- MsgCreateBalancerPool
- MsgCreateBinaryOptionsLimitOrder
- MsgCreateBinaryOptionsLimitOrder
- MsgCreateBinaryOptionsMarketOrder
- MsgCreateBinaryOptionsMarketOrder
- MsgCreateBridge
- MsgCreateCampaign
- MsgCreateClawbackVestingAccount
- MsgCreateClient
- MsgCreateConcentratedPool
- MsgCreateContinuousFund
- MsgCreateCosmWasmPool
- MsgCreateDenom
- MsgCreateDenom
- MsgCreateDenom
- MsgCreateDerivativeLimitOrder
- MsgCreateDerivativeLimitOrder
- MsgCreateDerivativeMarketOrder
- MsgCreateDerivativeMarketOrder
- MsgCreateFullRangePositionAndSuperfluidDelegate
- MsgCreateGauge
- MsgCreateGroup
- MsgCreateInsuranceFund
- MsgCreateMetaNode
- MsgCreateNamespace
- MsgCreatePeriodicVestingAccount
- MsgCreatePermanentLockedAccount
- MsgCreatePosition
- MsgCreateRateLimit
- MsgCreateResourceNode
- MsgCreateSpotLimitOrder
- MsgCreateSpotLimitOrder
- MsgCreateSpotMarketOrder
- MsgCreateSpotMarketOrder
- MsgCreateStableswapPool
- MsgCreateTokenPair
- MsgCreateTradeRoute
- MsgCreateValidator
- MsgCreateValidator
- MsgCreateVestingAccount
- MsgCreateVestingAccount
- MsgCreateVestingPool
- MsgDeactivateContract
- MsgDecreasePositionMargin
- MsgDecreasePositionMargin
- MsgDelegate
- MsgDelegate
- MsgDelegateBondedTokens
- MsgDelegateToValidatorSet
- MsgDeleteAirdrop
- MsgDeleteClaimRecord
- MsgDeleteClientCreator
- MsgDeleteOutput
- MsgDeleteTokenPair
- MsgDeleteTradeRoute
- MsgDeleteValidator
- MsgDelistGasPrice
- MsgDelistStaking
- MsgDeposit
- MsgDeposit
- MsgDeposit
- MsgDeposit
- MsgDeposit
- MsgDepositClaim
- MsgDepositForBurn
- MsgDepositForBurnWithCaller
- MsgDepositValidatorRewardsPool
- MsgDepositValidatorRewardsPool
- MsgDeprecateHostZone
- MsgDerivativeMarketParamUpdate
- MsgDisableAttester
- MsgDisableBridge
- MsgEditValidator
- MsgEditValidator
- MsgEmergencySettleMarket
- MsgEmergencySettleMarket
- MsgEmitIBCAck
- MsgEnableAttester
- MsgEnableCampaign
- MsgERC20DeployedClaim
- MsgErrataTx
- MsgErrataTxQuorum
- MsgEthereumTx
- MsgEthereumTx
- MsgEthereumTx
- MsgEthereumTx
- MsgExchangeEnable
- MsgExec
- MsgExecLegacyContent
- MsgExecute
- MsgExecuteContract
- MsgExecuteContract
- MsgExecuteContractCompat
- MsgExecuteJSON
- MsgExecuteMessages
- MsgExitPool
- MsgExitSwapExternAmountOut
- MsgExitSwapShareAmountIn
- MsgExpiryFuturesMarketLaunch
- MsgExtendLockup
- MsgExternalTransfer
- MsgExternalTransfer
- MsgFeeDiscount
- MsgFileUpload
- MsgFinalizeTokenDeposit
- MsgFinalizeTokenWithdrawal
- MsgForceTransfer
- MsgForceUnlock
- MsgFoundationDeposit
- MsgFundCommunityPool
- MsgFundCommunityPool
- MsgFundCommunityPool
- MsgFundVestingAccount
- MsgGovExecute
- MsgGovExecuteJSON
- MsgGovPublish
- MsgGovScript
- MsgGovScriptJSON
- MsgGrant
- MsgGrantAllowance
- MsgIBCSoftwareUpgrade
- MsgIncreaseCounter
- MsgIncreasePositionMargin
- MsgIncreasePositionMargin
- MsgInitialClaim
- MsgInitiateTokenDeposit
- MsgInitiateTokenWithdrawal
- MsgInstantBinaryOptionsMarketLaunch
- MsgInstantBinaryOptionsMarketLaunch
- MsgInstantExpiryFuturesMarketLaunch
- MsgInstantiateContract
- MsgInstantiateContract
- MsgInstantiateContract2
- MsgInstantiateOracle
- MsgInstantPerpetualMarketLaunch
- MsgInstantSpotMarketLaunch
- MsgInstantSpotMarketLaunch
- MsgJoinPool
- MsgJoinSwapExternAmountIn
- MsgJoinSwapShareAmountOut
- MsgKickMetaNodeVote
- MsgLink
- MsgLinkAddresses
- MsgLinkTokenPair
- MsgLiquidateCrossMarginPool
- MsgLiquidatePosition
- MsgLiquidatePosition
- MsgLiquidStake
- MsgLiquidStake
- MsgLiquidStake
- MsgLoadTest
- MsgLockAndSuperfluidDelegate
- MsgLockTokens
- MsgLSMLiquidStake
- MsgMarketForcedSettlement
- MsgMetaNodeRegistrationVote
- MsgMigrateContract
- MsgMigrateContract
- MsgMigrateContract
- MsgMigrateToken
- MsgMimir
- MsgMint
- MsgMint
- MsgMintTokens
- MsgModuleQuerySafe
- MsgMoveAvailableVesting
- MsgMoveAvailableVestingByDenoms
- MsgMultiSend
- MsgNetworkFee
- MsgNetworkFeeQuorum
- MsgNodePauseChain
- MsgObservedTxIn
- MsgObservedTxOut
- MsgObservedTxQuorum
- MsgOffsetPosition
- MsgOverwriteDelegationRecord
- MsgOverwriteDelegationRecord
- MsgOverwriteRedemptionRecord
- MsgOverwriteRedemptionRecord
- MsgOverwriteUnbondingRecord
- MsgOverwriteUnbondingRecord
- MsgPauseBurningAndMinting
- MsgPauseSendingAndReceivingMessages
- MsgPerpetualMarketLaunch
- MsgPinCodes
- MsgPlaceBid
- MsgPrepay
- MsgPriceFeedQuorumBatch
- MsgPrivilegedExecuteContract
- MsgPrivilegedExecuteContract
- MsgProposeOutput
- MsgProposeUpgrade
- MsgPruneAllowances
- MsgPublish
- MsgRebalanceValidators
- MsgReceiveMessage
- MsgRecordBatch
- MsgRecoverClient
- MsgRecvPacket
- MsgRecvPacket
- MsgRedeemStake
- MsgRedeemStake
- MsgRedeemStake
- MsgRedelegateValidatorSet
- MsgRefreshRedemptionRate
- MsgRefreshRedemptionRate
- MsgRegisterAccount
- MsgRegisterAttestorSet
- MsgRegisterContract
- MsgRegisterCounterparty
- MsgRegisterERC20
- MsgRegisterERC20
- MsgRegisterHostZone
- MsgRegisterInterchainAccount
- MsgRegisterMigrationInfo
- MsgRegisterMigrationInfo
- MsgRegisterPreinstalls
- MsgRegisterTokenPriceQuery
- MsgRejectUpgrade
- MsgRelayChainlinkPrices
- MsgRelayCoinbaseMessages
- MsgRelayOracleData
- MsgRelayPriceFeedPrice
- MsgRelayProviderPrices
- MsgRelayPythPrices
- MsgRelayPythProPrices
- MsgRelaySedaFastPrices
- MsgRelayStorkPrices
- MsgRemoveAttestor
- MsgRemoveAuthenticator
- MsgRemoveBridgeExecutor
- MsgRemoveCampaign
- MsgRemoveChecksum
- MsgRemoveCodeUploadParamsAddresses
- MsgRemoveEmergencySubmitters
- MsgRemoveFeeWhitelistAddresses
- MsgRemoveMetaNode
- MsgRemoveOracle
- MsgRemoveRateLimit
- MsgRemoveRemoteTokenMessenger
- MsgRemoveResourceNode
- MsgRemoveSchedule
- MsgRemoveTokenPriceQuery
- MsgReplaceDepositForBurn
- MsgReplaceMessage
- MsgRequestBatch
- MsgRequestRedemption
- MsgRestoreInterchainAccount
- MsgRestoreOracleICA
- MsgResumeHostZone
- MsgResumeHostZone
- MsgResumeHostZone
- MsgRevoke
- MsgRevokeAllowance
- MsgRevokeEthereumBlacklist
- MsgRewardsOptOut
- MsgRewardsOptOut
- MsgScheduleExecuteContract
- MsgScript
- MsgScriptJSON
- MsgSend
- MsgSend
- MsgSendMessage
- MsgSendMessageWithCaller
- MsgSendPacket
- MsgSendToEth
- MsgSendToVestingAccount
- MsgSendTx
- MsgSetActiveState
- MsgSetAirdropAllocations
- MsgSetBaseDenoms
- MsgSetBeforeSendHook
- MsgSetBridgeInfo
- MsgSetCommunityPoolRebate
- MsgSetContractGovernance
- MsgSetDenomMetadata
- MsgSetDenomMetadata
- MsgSetDenomMetadata
- MsgSetDenomPairTakerFee
- MsgSetDeveloperAccount
- MsgSetFeeTokens
- MsgSetHotRoutes
- MsgSetInfoByPoolType
- MsgSetIPAddress
- MsgSetMaxBurnAmountPerMessage
- MsgSetMaxPoolPointsPerBlock
- MsgSetMaxPoolPointsPerTx
- MsgSetNodeKeys
- MsgSetOperatorAddress
- MsgSetOperatorAddress
- MsgSetOrchestratorAddresses
- MsgSetRegisteredAlloyedPool
- MsgSetRewardReceiverAddress
- MsgSetSendEnabled
- MsgSetTakerFeeShareAgreementForDenom
- MsgSetValidatorSetPreference
- MsgSetVersion
- MsgSetWithdrawAddress
- MsgSlashingResourceNode
- MsgSoftwareUpgrade
- MsgSolvency
- MsgSolvencyQuorum
- MsgSpendFeePool
- MsgSplitRouteSwapExactAmountIn
- MsgSplitRouteSwapExactAmountOut
- MsgSplitVesting
- MsgSpotMarketLaunch
- MsgSpotMarketParamUpdate
- MsgStableSwapAdjustScalingFactors
- MsgStoreAndInstantiateContract
- MsgStoreAndMigrateContract
- MsgStoreCode
- MsgStoreCode
- MsgStoreCode
- MsgSubaccountTransfer
- MsgSubaccountTransfer
- MsgSubmitBadSignatureEvidence
- MsgSubmitEvidence
- MsgSubmitMisbehaviour
- MsgSubmitProposal
- MsgSubmitProposal
- MsgSubmitQueryResponse
- MsgSubmitTx
- MsgSudoContract
- MsgSuperfluidDelegate
- MsgSuperfluidUnbondLock
- MsgSuperfluidUndelegate
- MsgSuperfluidUndelegateAndUnbondLock
- MsgSwapExactAmountIn
- MsgSwapExactAmountIn
- MsgSwapExactAmountOut
- MsgSwapExactAmountOut
- MsgTimeout
- MsgTimeout
- MsgTimeoutOnClose
- MsgToggleConversion
- MsgToggleConversion
- MsgToggleIbcSwitch
- MsgToggleOracle
- MsgToggleTradeController
- MsgTradingRewardCampaignLaunch
- MsgTradingRewardCampaignUpdate
- MsgTradingRewardPendingPointsUpdate
- MsgTransfer
- MsgTransfer
- MsgTransferPositions
- MsgTssKeysignFail
- MsgTssPool
- MsgUnbondConvertAndStake
- MsgUndelegate
- MsgUndelegate
- MsgUndelegateFromRebalancedValidatorSet
- MsgUndelegateFromValidatorSet
- MsgUnderwrite
- MsgUnjail
- MsgUnlinkTokenPair
- MsgUnlockAndMigrateSharesToFullRangeConcentratedPosition
- MsgUnpauseBurningAndMinting
- MsgUnpauseSendingAndReceivingMessages
- MsgUnpinCodes
- MsgUnPoolWhitelistedPool
- MsgUpdateACL
- MsgUpdateActorRoles
- MsgUpdateAdmin
- MsgUpdateAdmin
- MsgUpdateAdmin
- MsgUpdateAdmin
- MsgUpdateAirdrop
- MsgUpdateAttesterManager
- MsgUpdateAuction
- MsgUpdateBatchInfo
- MsgUpdateChallenger
- MsgUpdateChannelId
- MsgUpdateClient
- MsgUpdateClientConfig
- MsgUpdateContract
- MsgUpdateContractLabel
- MsgUpdateDenomParam
- MsgUpdateDerivativeMarket
- MsgUpdateDerivativeMarket
- MsgUpdateEffectiveDeposit
- MsgUpdateFinalizationPeriod
- MsgUpdateHostZoneParams
- MsgUpdateImplmentationProposal
- MsgUpdateInnerRedemptionRateBounds
- MsgUpdateInnerRedemptionRateBounds
- MsgUpdateInnerRedemptionRateBounds
- MsgUpdateInstantiateConfig
- MsgUpdateMachineWhitelist
- MsgUpdateMachineWhitelistProposal
- MsgUpdateMaxMessageBodySize
- MsgUpdateMetadata
- MsgUpdateMetaNode
- MsgUpdateMetaNodeDeposit
- MsgUpdateMinGasPrices
- MsgUpdateMintersParams
- MsgUpdateNamespace
- MsgUpdateOracle
- MsgUpdateOracleConfig
- MsgUpdateOwner
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdateParams
- MsgUpdatePauser
- MsgUpdatePermissionedRelayers
- MsgUpdateProposer
- MsgUpdateRateLimit
- MsgUpdateResourceNode
- MsgUpdateResourceNodeDeposit
- MsgUpdateSequencer
- MsgUpdateSignatureThreshold
- MsgUpdateSpotMarket
- MsgUpdateSpotMarket
- MsgUpdateSubaccountRiskProfile
- MsgUpdateSubDistributorBurnShareParam
- MsgUpdateSubDistributorDestinationShareParam
- MsgUpdateSubDistributorParam
- MsgUpdateTokenController
- MsgUpdateTradeRoute
- MsgUpdateUserAllocation
- MsgUpdateValidatorSharesExchRate
- MsgUpdateVestingFunder
- MsgUpgradeClient
- MsgUpgradeProposalPassed
- MsgValsetConfirm
- MsgValsetUpdatedClaim
- MsgVolumeReport
- MsgVote
- MsgVote
- MsgVoteWeighted
- MsgVoteWeighted
- MsgWhitelistGasPrice
- MsgWhitelistStaking
- MsgWithdraw
- MsgWithdraw
- MsgWithdraw
- MsgWithdrawAllAvailable
- MsgWithdrawClaim
- MsgWithdrawDelegationRewards
- MsgWithdrawDelegatorReward
- MsgWithdrawPosition
- MsgWithdrawValidatorCommission
- ProcessBlockRequest
- QuorumErrataTx
- QuorumNetworkFee
- QuorumPriceFeedBatch
- QuorumSolvency
- QuorumTx
- RaAuthenticate
- RequestApplySnapshotChunk
- RequestCheckTx
- RequestCommit
- RequestEcho
- RequestExtendVote
- RequestFinalizeBlock
- RequestFlush
- RequestInfo
- RequestInitChain
- RequestListSnapshots
- RequestLoadSnapshotChunk
- RequestOfferSnapshot
- RequestPrepareProposal
- RequestProcessProposal
- RequestQuery
- RequestVerifyVoteExtension
- StreamRequest
- StreamRequest
- SubscribeRequest
Properties
- declarationId → CosmosProtoTypeUrl
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protoValues
→ List<
Object?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onServiceResponse(
List< int> bytes) → RESPONSE -
onServiceResponseJson(
Map< String, dynamic> json) → RESPONSE -
protoConfig(
) → ProtoMessageConfig -
inherited
-
toAny(
) → Any -
inherited
-
toBase64(
) → String -
inherited
-
toBuffer(
) → List< int> -
inherited
-
toJson(
) → Map< String, dynamic> -
Dont change order of toJson
the key index must be equal to
protoConfigfields.inherited -
toJsonObject(
CosmosToJsonEncoding encoding, {CosmosBech32Config? config}) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited